@@ -104,11 +104,13 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     authorizationStatusLabel->setFont(authorizationStatusFont);
 
 
-    saveButton = new QPushButton(QIcon::fromTheme("document-save"),
+    saveButton = new QPushButton(QIcon::fromTheme("document-save",
+                                                  QIcon(":/images/button-save.png")),
                                  tr("&Save Details"));
     connect(saveButton, SIGNAL(clicked()),
             this, SLOT(saveDetails()));
-    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel"),
+    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                    QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"));
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(hide()));
