@@ -25,51 +25,46 @@ ASActivity::ASActivity(QVariantMap activityMap,
 {
     id = activityMap.value("id").toString();
 
+
+    // Get the author of the _activity_ (not the object)
+    this->asAuthor = new ASPerson(activityMap.value("actor").toMap(), this);
+
     // Get the object included with the activity: the post itself, or whatever
     this->asObject = new ASObject(activityMap.value("object").toMap(), this);
 
+    // If the object is a person, as in an activity where someone adds someone else
+    if (asObject->getType() == "person")
+    {
+        this->asPersonObject = new ASPerson(activityMap.value("object").toMap(), this);
+    }
+    else
+    {
+        // Otherwise, at least initialize empty, but valid
+        this->asPersonObject = new ASPerson(QVariantMap(), this);
+    }
+
+    // Get possible "target"
+    this->asTarget = new ASObject(activityMap.value("target").toMap(), this);
+
+    // FIXME: add bools hasAuthor, hasObject and hasTarget, maybe?
+
 
     // Activity verb: post, share...
     verb = activityMap.value("verb").toString();
 
-    QVariantMap authorMap;
     if (verb == "share")
     {
         shared = true;
-
-        // Get original author data
-        authorMap = this->asObject->getAuthorMap();
-
-        sharedByName = activityMap.value("actor").toMap().value("displayName").toString();
-        sharedById = activityMap.value("actor").toMap().value("id").toString();
-        if (sharedById.startsWith("acct:"))
-        {
-            sharedById.remove(0,5);
-        }
-        sharedByAvatar = activityMap.value("actor").toMap().value("image").toMap().value("url").toString();
+        sharedByName = asAuthor->getName();
+        sharedById = asAuthor->getId();
+        sharedByAvatar = asAuthor->getAvatar();
     }
     else
     {
         shared = false;
-
-        // Not a share, so no original author, just get the actor
-        authorMap = activityMap.value("actor").toMap();
     }
 
 
-    authorName = authorMap.value("displayName").toString();
-    authorAvatar = authorMap.value("image").toMap().value("url").toString();
-    authorId = authorMap.value("id").toString();
-    // For Author ID, remove the first 5 characters from the field, if they are "acct:"
-    // (users have acct: in front of the ID, but services like OFG don't)
-    if (authorId.startsWith("acct:"))
-    {
-        authorId.remove(0,5);
-    }
-    authorUrl = authorMap.value("url").toString();
-    authorHometown = authorMap.value("location").toMap().value("displayName").toString();
-    authorBio = authorMap.value("summary").toString();
-
     // Timestamps
     createdAt = activityMap.value("published").toString();
     updatedAt = activityMap.value("updated").toString();
@@ -146,13 +141,29 @@ ASActivity::~ASActivity()
 }
 
 
-// Getters!
+
+////// Getters!
+
+ASPerson *ASActivity::author()
+{
+    return this->asAuthor;
+}
 
 ASObject *ASActivity::object()
 {
     return this->asObject;
 }
 
+ASObject *ASActivity::target()
+{
+    return this->asTarget;
+}
+
+ASPerson *ASActivity::personObject()
+{
+    return this->asPersonObject;
+}
+
 
 QString ASActivity::getId()
 {
@@ -219,34 +230,3 @@ QString ASActivity::getSharedByAvatar()
 {
     return this->sharedByAvatar;
 }
-
-QString ASActivity::getAuthorName()
-{
-    return this->authorName;
-}
-
-QString ASActivity::getAuthorId()
-{
-    return this->authorId;
-}
-
-QString ASActivity::getAuthorAvatar()
-{
-    return this->authorAvatar;
-}
-
-QString ASActivity::getAuthorUrl()
-{
-    return this->authorUrl;
-}
-
-QString ASActivity::getAuthorHometown()
-{
-    return this->authorHometown;
-}
-
-QString ASActivity::getAuthorBio()
-{
-    return this->authorBio;
-}
-
