@@ -26,19 +26,18 @@ ASObject::ASObject(QVariantMap objectMap,
     this->originalObjectMap = objectMap;
 
     /// Meta information
-    id = objectMap.value("id").toString();
-    if (id.startsWith("acct:"))
-    {
-        id.remove(0,5);
-    }
+    id = ASPerson::cleanupId(objectMap.value("id").toString());
 
     type = objectMap.value("objectType").toString();
     url = objectMap.value("url").toString();
     createdAt = objectMap.value("published").toString();
     updatedAt = objectMap.value("updated").toString();
 
-    // FIXME: kind of basic...
-    location = objectMap.value("location").toMap().value("displayName").toString();
+    // FIXME: still missing some fields...
+    QVariantMap locationMap = objectMap.value("location").toMap();
+    locationName = locationMap.value("displayName").toString();
+    locationFormatted = locationMap.value("address").toMap().value("formatted").toString();
+    locationCountry = locationMap.value("address").toMap().value("country").toString();
 
 
     // Author
@@ -143,8 +142,18 @@ ASObject::ASObject(QVariantMap objectMap,
     }
 
 
+    // If it's a group, get member count, etc.
+    if (type == "group")
+    {
+        memberCount = objectMap.value("members").toMap().value("totalItems").toInt();
+        memberUrl = objectMap.value("members").toMap().value("url").toString();
+    }
+
+
+
     // Title can be in non-image posts, too!
     title = objectMap.value("displayName").toString();
+    summary = objectMap.value("summary").toString();
     content = objectMap.value("content").toString();
 
     likesCount = objectMap.value("likes").toMap().value("totalItems").toString();
@@ -215,9 +224,42 @@ QString ASObject::getUpdatedAt()
     return this->updatedAt;
 }
 
-QString ASObject::getLocation()
+QString ASObject::getLocationName()
 {
-    return this->location;
+    return this->locationName;
+}
+
+QString ASObject::getLocationFormatted()
+{
+    return this->locationFormatted;
+}
+
+QString ASObject::getLocationCountry()
+{
+    return this->locationCountry;
+}
+
+QString ASObject::getLocationTooltip()
+{
+    QString locationTooltip = this->locationFormatted;
+
+    if (!this->locationCountry.isEmpty())
+    {
+        if (!locationTooltip.isEmpty())
+        {
+            locationTooltip.append("\n");
+        }
+
+        locationTooltip.append("(" + this->locationCountry +  ")");
+    }
+
+    // If still empty, return informational string
+    if (locationTooltip.isEmpty())
+    {
+        locationTooltip = tr("No detailed location");
+    }
+
+    return locationTooltip;
 }
 
 
@@ -237,6 +279,11 @@ QString ASObject::getTitle()
     return this->title;
 }
 
+QString ASObject::getSummary()
+{
+    return this->summary;
+}
+
 QString ASObject::getContent()
 {
     return this->content;
@@ -272,6 +319,16 @@ QString ASObject::getAttachmentPureUrl()
     return this->attachmentPureUrl;
 }
 
+int ASObject::getMemberCount()
+{
+    return this->memberCount;
+}
+
+QString ASObject::getMemberUrl()
+{
+    return this->memberUrl;
+}
+
 QString ASObject::getLikesCount()
 {
     return this->likesCount;
