@@ -44,12 +44,16 @@ public:
     QString getUrl();
     QString getCreatedAt();
     QString getUpdatedAt();
-    QString getLocation();
+    QString getLocationName();
+    QString getLocationFormatted();
+    QString getLocationCountry();
+    QString getLocationTooltip();
 
     QString getDeletedTime();
     QString isLiked();
 
     QString getTitle();
+    QString getSummary();
     QString getContent();
 
     QString getImageUrl();
@@ -59,6 +63,9 @@ public:
     QString getMimeType();
     QString getAttachmentPureUrl();
 
+    int getMemberCount();
+    QString getMemberUrl();
+
     QString getLikesCount();
     QString getCommentsCount();
     QString getSharesCount();
@@ -86,13 +93,16 @@ private:
     QString url;
     QString createdAt;
     QString updatedAt;
-    QString location;
+    QString locationName;
+    QString locationFormatted;
+    QString locationCountry;
 
     QString deleted;
     QString liked;
 
 
     QString title;
+    QString summary;
     QString content;
 
     QString imageUrl;
@@ -102,6 +112,9 @@ private:
     QString mimeType;
     QString attachmentPureUrl; // To have filename with extension when using a proxyURL
 
+    int memberCount;
+    QString memberUrl;
+
     QString likesCount;
     QString commentsCount;
     QString sharesCount;
