@@ -23,11 +23,7 @@
 ASPerson::ASPerson(QVariantMap personMap,
                    QObject *parent) : QObject(parent)
 {
-    this->id = personMap.value("id").toString();
-    if (id.startsWith("acct:"))
-    {
-        id.remove(0,5);
-    }
+    this->id = this->cleanupId(personMap.value("id").toString());
     this->name = personMap.value("displayName").toString().trimmed();
     this->avatar = personMap.value("image").toMap().value("url").toString();
     this->url = personMap.value("url").toString();
@@ -55,6 +51,18 @@ QString ASPerson::getId()
     return id;
 }
 
+QString ASPerson::cleanupId(QString originalId)
+{
+    if (originalId.startsWith("acct:"))
+    {
+        originalId.remove(0,5);
+    }
+
+    return originalId;
+}
+
+
+
 QString ASPerson::getName()
 {
     return name;
