@@ -84,7 +84,8 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
                                  tr("&Done"));
     connect(doneButton, SIGNAL(clicked()),
             this, SLOT(setAudience()));
-    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel"),
+    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                    QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"));
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(close()));
