@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,12 +20,15 @@
 
 #include "avatarbutton.h"
 
+
 AvatarButton::AvatarButton(ASPerson *person,
                            PumpController *pumpController,
+                           GlobalObject *globalObject,
                            QSize avatarSize,
                            QWidget *parent) : QToolButton(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
 
     this->setPopupMode(QToolButton::InstantPopup);
     this->setStyleSheet("QToolButton { border: none }"
@@ -153,17 +156,33 @@ void AvatarButton::createAvatarMenu()
 
 
     this->avatarMenuFollowAction = new QAction("*follow/unfollow*", this);
-    // Only add "follow/unfollow" option, if we're not the author
+    // Connections and proper label come are set in setFollowUnfollow()
+
+    this->avatarMenuMessageAction = new QAction(QIcon::fromTheme("document-edit",
+                                                                 QIcon(":/images/button-edit.png")),
+                                                tr("Send message to %1")
+                                                .arg(this->authorName),
+                                                this);
+    connect(avatarMenuMessageAction, SIGNAL(triggered()),
+            this, SLOT(sendMessageToUser()));
+
+
+    // Only add "follow/unfollow" and "send message" options if we're not the author
     if (!userIsAuthor)
     {
         avatarMenu->addAction(avatarMenuFollowAction);
         this->setFollowUnfollow();
+
+        avatarMenu->addAction(avatarMenuMessageAction);
     }
 
+    //
     // More options can be added from outside, via addActionToMenu()
+    //
 }
 
 
+
 /*
  * Set the icon and text of the follow/unfollow option of the avatar menu
  * according to whether we're following that user or not
@@ -242,6 +261,14 @@ void AvatarButton::unfollowUser()
 }
 
 
+void AvatarButton::sendMessageToUser()
+{
+    this->globalObj->createMessageForContact(this->authorName, this->authorId);
+
+}
+
+
+
 /*
  * Redraw avatar after receiving it
  *
