@@ -21,26 +21,31 @@
 #include "comment.h"
 
 Comment::Comment(PumpController *pumpController,
-                 ASObject *object,
+                 GlobalObject *globalObject,
+                 ASObject *commentObject,
                  QWidget *parent) : QFrame(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
 
-    object->setParent(this); // reparent the passed object
+    commentObject->setParent(this); // reparent the passed object
 
     QSizePolicy sizePolicy;
     sizePolicy.setHeightForWidth(false);
     sizePolicy.setWidthForHeight(false);
-    sizePolicy.setHorizontalPolicy(QSizePolicy::MinimumExpanding);
-    sizePolicy.setVerticalPolicy(QSizePolicy::Maximum);
+    //sizePolicy.setHorizontalPolicy(QSizePolicy::MinimumExpanding);
+    //sizePolicy.setVerticalPolicy(QSizePolicy::Maximum);
+    sizePolicy.setHorizontalPolicy(QSizePolicy::Ignored);
+    sizePolicy.setVerticalPolicy(QSizePolicy::Preferred);
     this->setSizePolicy(sizePolicy);
+    this->setMinimumSize(10, 10); // Ensure something's visible at any time
     this->setMaximumHeight(4096);
 
 
-    this->commentId = object->getId();
-    this->objectType = object->getType();
+    this->commentId = commentObject->getId();
+    this->objectType = commentObject->getType();
 
-    QString commentAuthorId = object->author()->getId();;
+    QString commentAuthorId = commentObject->author()->getId();;
     if (commentAuthorId == pController->currentUserId())
     {
         commentIsOwn = true; // Comment is ours!
@@ -58,43 +63,47 @@ Comment::Comment(PumpController *pumpController,
 
 
     // Avatar pixmap
-    avatarButton = new AvatarButton(object->author(),
+    avatarButton = new AvatarButton(commentObject->author(),
                                     this->pController,
-                                    QSize(32,32));
+                                    this->globalObj,
+                                    QSize(32,32),
+                                    this);
 
 
     QFont commentsFont;
-    commentsFont.setPointSize(commentsFont.pointSize() - 1); // 1 point less than default
+    commentsFont.fromString(globalObj->getCommentsFont());
 
 
     // Name, with ID as tooltip
-    commentsFont.setBold(true);
+    QFont metadataFont;
+    metadataFont.setPointSize(metadataFont.pointSize() - 1); // 1 point less than default
+    metadataFont.setBold(true);
     if (commentIsOwn)
     {
-        commentsFont.setItalic(true);
+        metadataFont.setItalic(true);
     }
 
 
-    fullNameLabel = new QLabel(object->author()->getName());
-    if (object->author()->getName().isEmpty())
+    fullNameLabel = new QLabel(commentObject->author()->getName());
+    if (commentObject->author()->getName().isEmpty())
     {
         fullNameLabel->setText(commentAuthorId); // Use ID if name is empty
     }
     fullNameLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    fullNameLabel->setFont(commentsFont);
+    fullNameLabel->setFont(metadataFont);
     fullNameLabel->setToolTip(commentAuthorId);
 
 
     // Timestamps
-    createdAt = object->getCreatedAt();
-    updatedAt = object->getUpdatedAt();
+    createdAt = commentObject->getCreatedAt();
+    updatedAt = commentObject->getUpdatedAt();
 
-    commentsFont.setBold(false);
-    commentsFont.setItalic(true);
+    metadataFont.setBold(false);
+    metadataFont.setItalic(true);
 
     timestampLabel = new QLabel();
     timestampLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    timestampLabel->setFont(commentsFont);
+    timestampLabel->setFont(metadataFont);
     QString timestampTooltip = tr("Posted on %1")
                                 .arg(Timestamp::localTimeDate(createdAt));
     if (createdAt != updatedAt)
@@ -109,18 +118,18 @@ Comment::Comment(PumpController *pumpController,
 
 
     // Like and Delete "buttons"
-    commentsFont.setBold(true);
-    commentsFont.setItalic(false);
+    metadataFont.setBold(true);
+    metadataFont.setItalic(false);
 
     likeLabel = new QLabel("*like*");
     likeLabel->setContextMenuPolicy(Qt::NoContextMenu);
     likeLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    likeLabel->setFont(commentsFont);
+    likeLabel->setFont(metadataFont);
     likeLabel->setToolTip(tr("Like or unlike this comment"));
     connect(likeLabel, SIGNAL(linkActivated(QString)),
             this, SLOT(likeComment(QString)));
 
-    if (object->isLiked() == "true")
+    if (commentObject->isLiked() == "true")
     {
         commentIsLiked = true;
     }
@@ -136,7 +145,7 @@ Comment::Comment(PumpController *pumpController,
                             + "</a>");
     quoteLabel->setContextMenuPolicy(Qt::NoContextMenu);
     quoteLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    quoteLabel->setFont(commentsFont);
+    quoteLabel->setFont(metadataFont);
     quoteLabel->setToolTip(tr("Reply quoting this comment"));
     connect(quoteLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(saveCommentSelectedText()));
@@ -147,7 +156,7 @@ Comment::Comment(PumpController *pumpController,
     editLabel = new QLabel("<a href=\"edit://\">" + tr("Edit") + "</a>");
     editLabel->setContextMenuPolicy(Qt::NoContextMenu);
     editLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
-    editLabel->setFont(commentsFont);
+    editLabel->setFont(metadataFont);
     editLabel->setToolTip(tr("Modify this comment"));
     connect(editLabel, SIGNAL(linkActivated(QString)),
             this, SLOT(editComment()));
@@ -156,7 +165,7 @@ Comment::Comment(PumpController *pumpController,
     deleteLabel = new QLabel("<a href=\"delete://\">" + tr("Delete") + "</a>");
     deleteLabel->setContextMenuPolicy(Qt::NoContextMenu);
     deleteLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
-    deleteLabel->setFont(commentsFont);
+    deleteLabel->setFont(metadataFont);
     deleteLabel->setToolTip(tr("Erase this comment"));
     connect(deleteLabel, SIGNAL(linkActivated(QString)),
             this, SLOT(deleteComment()));
@@ -165,18 +174,18 @@ Comment::Comment(PumpController *pumpController,
     // The likes count
     likesCountLabel = new QLabel();
     likesCountLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    commentsFont.setBold(false);
-    likesCountLabel->setFont(commentsFont);
+    metadataFont.setBold(false);
+    likesCountLabel->setFont(metadataFont);
 
-    this->setLikesCount(object->getLikesCount(),
-                        object->getLastLikesList());
+    this->setLikesCount(commentObject->getLikesCount(),
+                        commentObject->getLastLikesList());
 
     // The comment itself
-    this->commentOriginalText = object->getContent();
+    this->commentOriginalText = commentObject->getContent();
 
 
     contentLabel = new QLabel();
-    contentLabel->setAlignment(Qt::AlignLeft);
+    contentLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     contentLabel->setFont(commentsFont);
     contentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     // To help screen readers add Qt::TextSelectableByKeyboard flag too;
@@ -218,7 +227,7 @@ Comment::Comment(PumpController *pumpController,
     rightLayout = new QVBoxLayout();
     rightLayout->addLayout(rightTopLayout, 0);
     rightLayout->addSpacing(4); // 4px vertical space separation
-    rightLayout->addWidget(contentLabel,   1);
+    rightLayout->addWidget(contentLabel,   1, Qt::AlignTop);
     rightLayout->addSpacing(2); // and 2px more as margin
 
 
