@@ -33,6 +33,7 @@
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "mischelpers.h"
 #include "timestamp.h"
 #include "asobject.h"
@@ -45,7 +46,8 @@ class Comment : public QFrame
 
 public:
     explicit Comment(PumpController *pumpController,
-                     ASObject *object,
+                     GlobalObject *globalObject,
+                     ASObject *commentObject,
                      QWidget *parent = 0);
     ~Comment();
 
@@ -109,6 +111,7 @@ private:
     QString commentSelectedText;
 
     PumpController *pController;
+    GlobalObject *globalObj;
 };
 
 #endif // COMMENT_H
