@@ -28,9 +28,6 @@ Composer::Composer(bool forPublisher)
     this->setAcceptRichText(true);
     this->setTabChangesFocus(true);
 
-    // FIXME: do something about the links being styled with user's color
-    //this->setStyleSheet("{ a:link { color: #FF0000;} }");
-
     QFont startConversationFont;
     startConversationFont.setPointSize(startConversationFont.pointSize() - 2);
 
@@ -199,6 +196,16 @@ int Composer::getMessageLabelHeight()
 }
 
 
+/*
+ * Hide placeholder message
+ *
+ */
+void Composer::hideInfoMessage()
+{
+    this->startConversationLabel->hide();
+}
+
+
 /*
  * Send a signal when getting focus
  *
@@ -206,12 +213,6 @@ int Composer::getMessageLabelHeight()
 void Composer::focusInEvent(QFocusEvent *event)
 {
     emit focusReceived(); // inform Publisher() or Commenter() that we have focus
-
-    if (this->forPublisher)
-    {
-        startConversationLabel->hide(); // hide placeholder message        
-    }
-
     QTextEdit::focusInEvent(event); // process standard event: allows context menu
 
     qDebug() << "Composer box got focus";
@@ -589,7 +590,7 @@ void Composer::pasteAsPlaintext()
     QString clipboardContents = QApplication::clipboard()->text(subtype,
                                                                 QClipboard::Clipboard);
 
-    this->makeNormal(); // Ensure normal text before insterting
+    this->makeNormal(); // Ensure normal text before inserting
     this->insertPlainText(clipboardContents);
 }
 
