@@ -20,19 +20,22 @@
 
 #include "configdialog.h"
 
-ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
+ConfigDialog::ConfigDialog(GlobalObject *globalObject,
+                           QString dataDirectory, int updateInterval,
                            int postsPerPageMain, int postsPerPageOther,
                            int tabsPosition, bool tabsMovable,
                            bool publicPosts, FDNotifications *notifier,
                            QWidget *parent) : QWidget(parent)
 {
+    this->globalObj = globalObject;
     this->fdNotifier = notifier;
 
     this->setWindowTitle(tr("Program Configuration") + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("configure"));
+    this->setWindowIcon(QIcon::fromTheme("configure",
+                                         QIcon(":/images/button-configure.png")));
     this->setWindowFlags(Qt::Window);
     this->setWindowModality(Qt::ApplicationModal);
-    this->setMinimumSize(520, 420);
+    this->setMinimumSize(560, 420);
 
     QSettings settings;
     settings.beginGroup("Configuration");
@@ -48,7 +51,7 @@ ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
                                   this);
 
 
-    /////////////////////////////////////////////////////////// Upper part
+    //////////////////////////////////////////////////////////////// Upper part
 
     // Tab 1, general options
     this->generalOptionsLayout = new QFormLayout();
@@ -109,11 +112,42 @@ ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
     generalOptionsLayout->addRow(tr("Network configuration"),
                                  proxyConfigButton);
 
+    filterEditorButton = new QPushButton(QIcon::fromTheme("view-filter"),
+                                         tr("Set Up F&ilters"));
+    connect(filterEditorButton, SIGNAL(clicked()),
+            this, SIGNAL(filterEditorRequested()));
+    generalOptionsLayout->addRow(tr("Filtering rules"),
+                                 filterEditorButton);
+
     generalOptionsWidget = new QWidget();
     generalOptionsWidget->setLayout(generalOptionsLayout);
 
 
-    // Tab 2, color options
+
+    // Tab 2, fonts
+    this->fontOptionsLayout = new QVBoxLayout();
+    fontPicker1 = new FontPicker(tr("Post Titles"),
+                                 globalObj->getPostTitleFont());
+    fontPicker2 = new FontPicker(tr("Post Contents"),
+                                 globalObj->getPostContentsFont());
+    fontPicker3 = new FontPicker(tr("Comments"),
+                                 globalObj->getCommentsFont());
+    fontPicker4 = new FontPicker(tr("Minor Feed"),
+                                 globalObj->getMinorFeedFont());
+    // FIXME: more for "Timestamps" or something else?
+
+    fontOptionsLayout->addWidget(fontPicker1);
+    fontOptionsLayout->addWidget(fontPicker2);
+    fontOptionsLayout->addWidget(fontPicker3);
+    fontOptionsLayout->addWidget(fontPicker4);
+    fontOptionsLayout->addStretch(1);
+
+    fontOptionsWidget = new QWidget();
+    fontOptionsWidget->setLayout(fontOptionsLayout);
+
+
+
+    // Tab 3, colors
     this->colorOptionsLayout = new QVBoxLayout();
 
     colorPicker1 = new ColorPicker(tr("You are among the recipients "
@@ -159,7 +193,7 @@ ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
 
 
 
-    // Tab 3, notification options
+    // Tab 4, notification and systray icon options
     notificationOptionsLayout = new QFormLayout();
 
     notificationStyleCombobox = new QComboBox();
@@ -173,6 +207,9 @@ ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
     notificationOptionsLayout->addRow(tr("Notification Style"),
                                       notificationStyleCombobox);
 
+
+    notificationOptionsLayout->addRow(new QLabel("\n" + tr("Notify when receiving:")));
+
     notifyNewTLCheckbox = new QCheckBox();
     notifyNewTLCheckbox->setChecked(settings.value("notifyNewTL", false).toBool());
     notificationOptionsLayout->addRow(tr("New posts"),
@@ -195,25 +232,26 @@ ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
 
     this->syncNotifierOptions();
 
-    notificationOptionsWidget = new QWidget();
-    notificationOptionsWidget->setLayout(notificationOptionsLayout);
+    QFrame *lineFrame = new QFrame();
+    lineFrame->setFrameStyle(QFrame::HLine);
+    lineFrame->setMinimumHeight(16);
+    notificationOptionsLayout->addRow(lineFrame);
 
 
-    // Tab 4, systray icon options
-    systrayOptionsLayout = new QFormLayout();
-    systrayOptionsLayout->setAlignment(Qt::AlignRight);
     systrayIconTypeCombobox = new QComboBox();
     systrayIconTypeCombobox->addItem(tr("Default"));
     systrayIconTypeCombobox->addItem(tr("System iconset, if available"));
     systrayIconTypeCombobox->addItem(tr("Show your current avatar"));
     systrayIconTypeCombobox->addItem(tr("Custom icon"));
     systrayIconTypeCombobox->setCurrentIndex(settings.value("systrayIconType", 0).toInt());
-    systrayOptionsLayout->addRow(tr("Icon &Type"),
-                                 systrayIconTypeCombobox);
+    notificationOptionsLayout->addRow(tr("System Tray Icon &Type"),
+                                      systrayIconTypeCombobox);
 
 
     systrayCustomIconButton = new QPushButton(tr("S&elect..."));
     systrayCustomIconFN = settings.value("systrayCustomIconFN").toString();
+    // FIXME: merge this with code used in pickCustomIconFile()
+    // and turn the warning messageBox into a label
     if (!QPixmap(systrayCustomIconFN).isNull())
     {
         systrayCustomIconButton->setIcon(QIcon(systrayCustomIconFN));
@@ -224,35 +262,37 @@ ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
     }
     connect(systrayCustomIconButton, SIGNAL(clicked()),
             this, SLOT(pickCustomIconFile()));
-    systrayOptionsLayout->addRow(tr("Custom &Icon"),
-                                 systrayCustomIconButton);
+    notificationOptionsLayout->addRow(tr("Custom &Icon"),
+                                      systrayCustomIconButton);
 
 
-    systrayOptionsWidget = new QWidget();
-    systrayOptionsWidget->setLayout(systrayOptionsLayout);
+    notificationOptionsWidget = new QWidget();
+    notificationOptionsWidget->setLayout(notificationOptionsLayout);
 
     settings.endGroup();
 
 
-    // Tab widget
+
+    //// Tab widget
     tabWidget = new QTabWidget();
     tabWidget->setSizePolicy(QSizePolicy::MinimumExpanding,
                              QSizePolicy::MinimumExpanding);
     tabWidget->addTab(generalOptionsWidget,
                       QIcon::fromTheme("preferences-other"),
                       tr("&General Options"));
+    tabWidget->addTab(fontOptionsWidget,
+                      QIcon::fromTheme("preferences-desktop-font"),
+                      tr("&Fonts"));
     tabWidget->addTab(colorOptionsWidget,
                       QIcon::fromTheme("preferences-desktop-color"),
                       tr("Co&lors"));
     tabWidget->addTab(notificationOptionsWidget,
                       QIcon::fromTheme("preferences-desktop-notification"),
-                      tr("&Notifications"));
-    tabWidget->addTab(systrayOptionsWidget,
-                      QIcon::fromTheme("preferences-desktop"),
-                      tr("S&ystem Tray"));
+                      tr("&Notifications and System Tray"));
 
 
-    //////////// Bottom part
+
+    /////////////////////////////////////////////////////////////// Bottom part
 
     // Label to show where the data directory is
     dataDirectoryLabel = new QLabel(tr("Dianara stores data in this folder:")
@@ -344,6 +384,15 @@ void ConfigDialog::saveConfiguration()
 
     settings.setValue("publicPosts", this->publicPostsCheckbox->isChecked());
 
+    settings.setValue("font1", this->fontPicker1->getFontInfo());
+    settings.setValue("font2", this->fontPicker2->getFontInfo());
+    settings.setValue("font3", this->fontPicker3->getFontInfo());
+    settings.setValue("font4", this->fontPicker4->getFontInfo());
+    this->globalObj->syncFontSettings(this->fontPicker1->getFontInfo(),
+                                      this->fontPicker2->getFontInfo(),
+                                      this->fontPicker3->getFontInfo(),
+                                      this->fontPicker4->getFontInfo());
+
     settings.setValue("color1", this->colorPicker1->getCurrentColor());
     settings.setValue("color2", this->colorPicker2->getCurrentColor());
     settings.setValue("color3", this->colorPicker3->getCurrentColor());
