@@ -39,6 +39,8 @@
 
 #include <QDebug>
 
+#include "globalobject.h"
+#include "fontpicker.h"
 #include "colorpicker.h"
 #include "notifications.h"
 #include "proxydialog.h"
@@ -49,7 +51,8 @@ class ConfigDialog : public QWidget
     Q_OBJECT
 
 public:
-    ConfigDialog(QString dataDirectory,
+    ConfigDialog(GlobalObject *globalObject,
+                 QString dataDirectory,
                  int updateInterval,
                  int postsPerPageMain,
                  int postsPerPageOther,
@@ -64,6 +67,7 @@ public:
 
 signals:
     void configurationChanged();
+    void filterEditorRequested();
 
 
 public slots:
@@ -88,10 +92,22 @@ private:
     QCheckBox *publicPostsCheckbox;
 
     QPushButton *proxyConfigButton;
-
     ProxyDialog *proxyDialog;
 
-    // Tab 2, color options
+    QPushButton *filterEditorButton;
+
+
+    // Tab 2, fonts
+    QWidget *fontOptionsWidget;
+    QVBoxLayout *fontOptionsLayout;
+
+    FontPicker *fontPicker1;
+    FontPicker *fontPicker2;
+    FontPicker *fontPicker3;
+    FontPicker *fontPicker4;
+
+
+    // Tab 3, colors
     QWidget *colorOptionsWidget;
     QVBoxLayout *colorOptionsLayout;
 
@@ -103,7 +119,7 @@ private:
     ColorPicker *colorPicker6;
 
 
-    // Tab 3, notification options
+    // Tab 4, notification and systray icon options
     QWidget *notificationOptionsWidget;
     QFormLayout *notificationOptionsLayout;
 
@@ -113,11 +129,6 @@ private:
     QCheckBox *notifyNewMWCheckbox;
     QCheckBox *notifyHLMWCheckbox;
 
-
-    // Tab 4, system tray icon options
-    QWidget *systrayOptionsWidget;
-    QFormLayout *systrayOptionsLayout;
-
     QComboBox *systrayIconTypeCombobox;
     QPushButton *systrayCustomIconButton;
 
@@ -134,6 +145,8 @@ private:
     QAction *closeAction;
 
     FDNotifications *fdNotifier;
+
+    GlobalObject *globalObj;
 };
 
 #endif // CONFIGDIALOG_H
