@@ -21,10 +21,12 @@
 #include "contactcard.h"
 
 ContactCard::ContactCard(PumpController *pumpController,
+                         GlobalObject *globalObject,
                          ASPerson *asPerson,
                          QWidget *parent)  :  QFrame(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
     asPerson->setParent(this); // reparent the person object
 
 
@@ -140,14 +142,23 @@ ContactCard::ContactCard(PumpController *pumpController,
     connect(openProfileAction, SIGNAL(triggered()),
             this, SLOT(openProfileInBrowser()));
 
+    sendMessageAction = new QAction(QIcon::fromTheme("document-edit",
+                                                     QIcon(":/images/button-edit.png")),
+                                    tr("Send Message"),
+                                    this);
+    connect(sendMessageAction, SIGNAL(triggered()),
+            this, SLOT(setMessagingModeForContact()));
+
     addToListMenu = new QMenu(tr("In Lists..."));
     addToListMenu->setIcon(QIcon::fromTheme("format-list-unordered"));
     addToListMenu->addAction("fake list 1")->setCheckable(true); // FIXME...
     addToListMenu->addAction("fake list 2")->setCheckable(true);
     addToListMenu->addAction("fake list 3")->setCheckable(true);
 
+
     optionsMenu = new QMenu("*options*");
     optionsMenu->addAction(openProfileAction);
+    optionsMenu->addAction(sendMessageAction);
     //optionsMenu->addMenu(addToListMenu); // Don't include it for now, until 1.3 /FIXME
 
 
@@ -276,6 +287,12 @@ void ContactCard::openProfileInBrowser()
     QDesktopServices::openUrl(this->contactUrl);
 }
 
+void ContactCard::setMessagingModeForContact()
+{
+    this->globalObj->createMessageForContact(this->contactName,
+                                             this->contactId);
+}
+
 
 
 /*
