@@ -21,10 +21,13 @@
 #include "contactlist.h"
 
 ContactList::ContactList(PumpController *pumpController,
+                         GlobalObject *globalObject,
                          QString listType,
                          QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
+
 
     this->filterLineEdit = new QLineEdit();
     filterLineEdit->setPlaceholderText(tr("Type a partial name or ID to find a contact...")
@@ -96,6 +99,7 @@ ContactList::ContactList(PumpController *pumpController,
 
     ASPerson *demoContactPerson = new ASPerson(demoContactData);
     ContactCard *demoContactCard = new ContactCard(this->pController,
+                                                   this->globalObj,
                                                    demoContactPerson);
     this->contactsLayout->addWidget(demoContactCard);
     this->contactsInList.append(demoContactCard);
@@ -136,6 +140,7 @@ void ContactList::setListContents(QString listType,
     {
         ASPerson *person = new ASPerson(contact.toMap());
         ContactCard *contactCard = new ContactCard(this->pController,
+                                                   this->globalObj,
                                                    person);
 
         contactInfoLineString = person->getName()
@@ -218,6 +223,7 @@ void ContactList::filterList(QString filterText)
 void ContactList::addSingleContact(ASPerson *contact)
 {
     ContactCard *card = new ContactCard(this->pController,
+                                        this->globalObj,
                                         contact,
                                         this);
 
