@@ -32,6 +32,7 @@
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "contactcard.h"
 
 
@@ -41,6 +42,7 @@ class ContactList : public QWidget
 
 public:
     explicit ContactList(PumpController *pumpController,
+                         GlobalObject *globalObject,
                          QString listType,
                          QWidget *parent = 0);
     ~ContactList();
@@ -71,6 +73,7 @@ protected:
 
 private:
     PumpController *pController;
+    GlobalObject *globalObj;
 
     QVBoxLayout *mainLayout;
 
