@@ -21,6 +21,7 @@
 #include "contactmanager.h"
 
 ContactManager::ContactManager(PumpController *pumpController,
+                               GlobalObject *globalObject,
                                QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
@@ -71,7 +72,9 @@ ContactManager::ContactManager(PumpController *pumpController,
 
 
     // Widgets for list of 'following' and 'followers'
-    this->followingWidget = new ContactList(this->pController, "following");
+    this->followingWidget = new ContactList(this->pController,
+                                            globalObject,
+                                            "following");
     connect(pController, SIGNAL(contactFollowed(ASPerson*)),
             followingWidget, SLOT(addSingleContact(ASPerson*)));
     connect(pController, SIGNAL(contactUnfollowed(ASPerson*)),
@@ -81,7 +84,9 @@ ContactManager::ContactManager(PumpController *pumpController,
             this, SLOT(changeFollowingCount(int)));
 
 
-    this->followersWidget = new ContactList(this->pController, "followers");
+    this->followersWidget = new ContactList(this->pController,
+                                            globalObject,
+                                            "followers");
 
 
     // Widget for the list of 'person lists'
@@ -121,8 +126,9 @@ ContactManager::ContactManager(PumpController *pumpController,
                            SLOT(refreshPersonLists()));
 
 
-    optionsButton = new QPushButton(QIcon::fromTheme("configure"),
-                                    tr("Optio&ns"));
+    optionsButton = new QPushButton(QIcon::fromTheme("configure",
+                                                     QIcon(":/images/button-configure.png")),
+                                    "");
     optionsButton->setMenu(optionsMenu);
 
 
