@@ -40,8 +40,7 @@ class DownloadWidget : public QFrame
 
 public:
     explicit DownloadWidget(QString fileUrl,
-                            QString postType,
-                            QString authorId,
+                            QString suggestedFN,
                             PumpController *pumpController,
                             QWidget *parent = 0);
     ~DownloadWidget();
@@ -75,6 +74,7 @@ private:
     PumpController *pController;
     QNetworkReply *networkReply;
     QFile downloadedFile;
+    bool downloading;
 };
 
 #endif // DOWNLOADWIDGET_H
