@@ -125,7 +125,8 @@ int FilterChecker::validateActivity(ASActivity *activity)
         }
     }
 
-    QString activityDescription = activity->getContent();
+    // Remove links from activity description, so it's easier to write filtering rules
+    QString activityDescription = MiscHelpers::htmlWithoutLinks(activity->getContent());
     foreach (QStringList description, filteredDescription)
     {
         if (activityDescription.contains(description.first(), Qt::CaseInsensitive))
