@@ -22,10 +22,15 @@
 
 ImageViewer::ImageViewer(QString fileURI,
                          QString title,
+                         QString suggestedFN,
+                         bool isAnimated,
                          QWidget *parent) : QWidget(parent)
 {
     this->setMinimumSize(420, 320);
 
+    this->suggestedFilename = suggestedFN;
+    this->imageIsAnimated = isAnimated;
+
     QString tooltipTitle;
     if (title.isEmpty())
     {
@@ -39,7 +44,6 @@ ImageViewer::ImageViewer(QString fileURI,
     fileURI.remove(0, 7); // remove "image:/" from filename URI
     this->originalFileURI = fileURI;
 
-    QDesktopWidget desktopWidget;
     originalPixmap = QPixmap(originalFileURI);
     QString resolution = QString("%1x%2")
                          .arg(originalPixmap.width())
@@ -48,6 +52,7 @@ ImageViewer::ImageViewer(QString fileURI,
     QString imageDetails = resolution + ", "
                            + MiscHelpers::fileSizeString(originalFileURI);
 
+
     this->setWindowTitle(tr("Image") + ": " + title + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("folder-image"));
 
@@ -66,6 +71,22 @@ ImageViewer::ImageViewer(QString fileURI,
     connect(saveImageButton, SIGNAL(clicked()),
             this, SLOT(saveImage()));
 
+
+    if (imageIsAnimated)
+    {
+        this->movie = new QMovie(this);
+        movie->setFileName(this->originalFileURI);
+        movie->start();
+
+        imageLabel->setMovie(movie);
+
+        restartButton = new QPushButton(QIcon::fromTheme("media-playback-start"),
+                                        tr("&Restart Animation"));
+        connect(restartButton, SIGNAL(clicked()),
+                this, SLOT(restartAnimation()));
+    }
+
+
     infoLabel = new QLabel(imageDetails);
     infoLabel->setAlignment(Qt::AlignCenter);
 
@@ -81,6 +102,10 @@ ImageViewer::ImageViewer(QString fileURI,
     // Layout
     buttonsLayout = new QHBoxLayout();
     buttonsLayout->addWidget(saveImageButton);
+    if (imageIsAnimated)
+    {
+        buttonsLayout->addWidget(restartButton);
+    }
     buttonsLayout->addWidget(infoLabel, 1);
     buttonsLayout->addWidget(closeButton);
 
@@ -91,17 +116,12 @@ ImageViewer::ImageViewer(QString fileURI,
 
 
     // Set initial window size according to image size and desktop (screen) size
-    int windowHeight = originalPixmap.height() + 100;
-    if (windowHeight > desktopWidget.height())
-    {
-        windowHeight = desktopWidget.height();
-    }
+    QDesktopWidget desktopWidget;
+    int windowWidth = qMin(originalPixmap.width() + 100, // Some margin for the window itself
+                           desktopWidget.availableGeometry().width());
 
-    int windowWidth = originalPixmap.width() + 100;
-    if (windowWidth > desktopWidget.width())
-    {
-        windowWidth = desktopWidget.width();
-    }
+    int windowHeight = qMin(originalPixmap.height() + 100,
+                            desktopWidget.availableGeometry().height());
 
     this->resize(windowWidth, windowHeight);
 
@@ -144,8 +164,8 @@ void ImageViewer::saveImage()
 
     QString filename;
     filename = QFileDialog::getSaveFileName(this, tr("Save Image As..."),
-                                            QDir::homePath(),
-                                            tr("Image files") + "(*.jpg *.png);;"
+                                            QDir::homePath() + "/" + suggestedFilename,
+                                            tr("Image files") + " (*.jpg *.png);;"
                                             + tr("All files") + " (*)");
 
     if (!filename.isEmpty())
@@ -153,6 +173,7 @@ void ImageViewer::saveImage()
         // Save pixmap from original file
         savedCorrectly = QPixmap(this->originalFileURI).save(filename);
 
+        // FIXME: change this to directly copy the unmodified original instead
         if (!savedCorrectly)
         {
             QMessageBox::warning(this,
@@ -164,6 +185,15 @@ void ImageViewer::saveImage()
     }
 }
 
+void ImageViewer::restartAnimation()
+{
+    if (imageIsAnimated)
+    {
+        this->movie->stop();
+        this->movie->start();
+    }
+}
+
 
 
 /****************************************************************************/
@@ -173,31 +203,44 @@ void ImageViewer::saveImage()
 
 void ImageViewer::closeEvent(QCloseEvent *event)
 {
-    qDebug() << "ImageViewer::closeEvent()";
-    event->accept();
+    qDebug() << "ImageViewer::closeEvent(); hiding and destroying widget!";
+    event->ignore();
 
+    this->hide();
     this->deleteLater();
 }
 
+void ImageViewer::hideEvent(QHideEvent *event)
+{
+    qDebug() << "ImageViewer::hideEvent()";
+    event->accept();
+}
+
+
 void ImageViewer::resizeEvent(QResizeEvent *event)
 {
     qDebug() << "ImageViewer::resizeEvent()";
 
-    int width = imageLabel->width() - 16;   // 16px as margin
-    if (width > originalPixmap.width())
-    {
-        width = originalPixmap.width();
-    }
+    int width = qMin(imageLabel->width() - 16,   // 16px as margin
+                     originalPixmap.width());
+    int height = qMin(imageLabel->height() - 16,
+                      originalPixmap.height());
+    // FIXME: maybe for animated images (usually small GIFs)
+    // the image could be allowed to grow to > 1x
 
-    int height = imageLabel->height() - 16;
-    if (height > originalPixmap.height())
+    if (!this->imageIsAnimated)
     {
-        height = originalPixmap.height();
+        imageLabel->setPixmap(originalPixmap.scaled(width, height,
+                                                    Qt::KeepAspectRatio,
+                                                    Qt::SmoothTransformation));
+    }
+    else
+    {
+        QSize movieSize(originalPixmap.width(),
+                        originalPixmap.height());
+        movieSize.scale(width, height, Qt::KeepAspectRatio);
+        movie->setScaledSize(movieSize);
     }
-
-    imageLabel->setPixmap(originalPixmap.scaled(width, height,
-                                                Qt::KeepAspectRatio,
-                                                Qt::SmoothTransformation));
 
     event->accept();
 }
