@@ -34,6 +34,7 @@
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QPushButton>
+#include <QMovie>
 
 #include <QDebug>
 
@@ -46,6 +47,8 @@ class ImageViewer : public QWidget
 public:
     explicit ImageViewer(QString fileURI,
                          QString title,
+                         QString suggestedFN,
+                         bool isAnimated,
                          QWidget *parent = 0);
     ~ImageViewer();
     void createContextMenu();
@@ -56,10 +59,12 @@ signals:
 
 public slots:
     void saveImage();
+    void restartAnimation();
 
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
+    virtual void hideEvent(QHideEvent *event);
     virtual void resizeEvent(QResizeEvent *event);
     virtual void keyPressEvent(QKeyEvent *event);
     virtual void contextMenuEvent(QContextMenuEvent *event);
@@ -71,6 +76,7 @@ private:
 
     QHBoxLayout *buttonsLayout;
     QPushButton *saveImageButton;
+    QPushButton *restartButton;
     QLabel *infoLabel;
     QPushButton *closeButton;
 
@@ -78,6 +84,9 @@ private:
 
     QPixmap originalPixmap;
     QString originalFileURI;
+    bool imageIsAnimated;
+    QMovie *movie;
+    QString suggestedFilename;
 };
 
 #endif // IMAGEVIEWER_H
