@@ -246,12 +246,7 @@ void ListsManager::setPersonsInList(QVariantList personList, QString listUrl)
         // FIXME: this should use ASPerson()
         QVariantMap personMap = personVariant.toMap();
 
-        QString id = personMap.value("id").toString();
-        if (id.startsWith("acct:"))
-        {
-            id.remove(0, 5);
-        }
-
+        QString id = ASPerson::cleanupId(personMap.value("id").toString());
         QString name = personMap.value("displayName").toString();
         QString avatar = personMap.value("image").toMap().value("url").toString();
 
@@ -455,11 +450,6 @@ void ListsManager::addPersonItemToList(QString personId,
                                        QString personName,
                                        QString avatarUrl)
 {
-    if (personId.startsWith("acct:"))
-    {
-        personId.remove(0,5);
-    }
-
     QTreeWidgetItem *newItem = this->createPersonItem(personId,
                                                       personName,
                                                       avatarUrl);
@@ -480,7 +470,7 @@ void ListsManager::addPersonItemToList(QString personId,
 
 void ListsManager::removePersonItemFromList(QString personId)
 {
-    if (personId == "acct:" + listsTreeWidget->currentItem()->text(1))
+    if (personId == listsTreeWidget->currentItem()->text(1))
     {
         QTreeWidgetItem *parentList = listsTreeWidget->currentItem()->parent();
         delete listsTreeWidget->currentItem();
