@@ -44,12 +44,16 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     if (currentIconset.isEmpty() || currentIconset == "hicolor")
     {
         qDebug() << ">> No system iconset (or hicolor) configured; trying to use Oxygen";
-        QIcon::setThemeName("oxygen"); // VERY TMPFIX
+        QIcon::setThemeName("oxygen"); // VERY TMP; FIXME
     }
 
     // Network control
     pumpController = new PumpController(this);
 
+    // Global object to connect different classes directly
+    globalObject = new GlobalObject(this);
+
+
     // Filter checker
     filterChecker = new FilterChecker(this);
 
@@ -97,6 +101,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     userIdLabel = new QLabel();
     userIdLabel->setWordWrap(true);
     userIdLabel->setFont(userDetailsFont);
+    userIdLabel->setSizePolicy(QSizePolicy::Ignored,
+                               QSizePolicy::Minimum);
 
     userDetailsFont.setBold(false);
     userDetailsFont.setItalic(false);
@@ -119,15 +125,17 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     leftPanel = new QToolBox(); // For now, only one "section"...
 
-    meanwhileFeed = new MinorFeed(pumpController, filterChecker);
-    connect(meanwhileFeed, SIGNAL(newItemsCountChanged(int)),
-            this, SLOT(setMinorFeedTitle(int)));
+    meanwhileFeed = new MinorFeed(pumpController,
+                                  globalObject,
+                                  filterChecker);
+    connect(meanwhileFeed, SIGNAL(newItemsCountChanged(int,int)),
+            this, SLOT(setMinorFeedTitle(int,int)));
     connect(meanwhileFeed, SIGNAL(newItemsReceived(int,int)),
             this, SLOT(notifyMinorFeedUpdate(int,int)));
     leftPanel->addItem(meanwhileFeed,
                        QIcon::fromTheme("clock"),
                        "*meanwhile*");
-    this->setMinorFeedTitle(0); // Set initial title (0 new)
+    this->setMinorFeedTitle(0, 0); // Set initial title (0 new, 0 HL)
 
 
     leftSideWidget = new QWidget();
@@ -136,6 +144,28 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     leftLayout->addLayout(leftTopLayout);       // Avatar + user info
     leftLayout->addSpacing(2);
     leftLayout->addWidget(leftPanel);           // Meanwhile feed
+
+////////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////////////////////// TMP GROUP MANAGER STUFF
+////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
+#if 0
+    GroupsManager *TMPGROUPSMANAGER = new GroupsManager(this->pumpController,
+                                                        this);
+
+    QPushButton *TMPEDITGROUPSBUTTON = new QPushButton(QIcon::fromTheme("user-group-properties"),
+                                                       "*MANAGE GROUPS*");
+    connect(TMPEDITGROUPSBUTTON, SIGNAL(clicked()),
+            TMPGROUPSMANAGER, SLOT(show()));
+    this->leftLayout->addWidget(TMPEDITGROUPSBUTTON);
+#endif
+////////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////////////////////// TMP GROUP MANAGER STUFF
+////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
+
     this->leftSideWidget->setLayout(leftLayout);
 
 
@@ -144,7 +174,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     rightLayout = new QVBoxLayout();
     rightLayout->setContentsMargins(0, 1, 1, 1);
 
-    publisher = new Publisher(pumpController);
+    publisher = new Publisher(pumpController,
+                              globalObject,
+                              this);
 
 
     /// START SETTING UP TIMELINES
@@ -154,6 +186,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     mainTimeline = new TimeLine(TimeLine::TimelineTypeMain,
                                 pumpController,
+                                globalObject,
                                 filterChecker,
                                 this);
     mainTimelineScrollArea = new QScrollArea();
@@ -164,18 +197,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     mainTimelineScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     connect(mainTimeline, SIGNAL(scrollTo(QAbstractSlider::SliderAction)),
             this, SLOT(scrollMainTimelineTo(QAbstractSlider::SliderAction)));
-    connect(mainTimeline, SIGNAL(timelineRendered(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
-    connect(mainTimeline, SIGNAL(unreadPostsCountChanged(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
+    connect(mainTimeline, SIGNAL(timelineRendered(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
+    connect(mainTimeline, SIGNAL(unreadPostsCountChanged(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
 
-    connect(mainTimeline, SIGNAL(timelineRendered(int,int,int)),
+    connect(mainTimeline, SIGNAL(timelineRendered(int,int,int,int)),
             this, SLOT(notifyTimelineUpdate(int,int,int)));
 
-    // for post editing
-    connect(mainTimeline, SIGNAL(postEditRequested(QString,QString,QString)),
-            publisher, SLOT(setEditingMode(QString,QString,QString)));
-
     // To ensure comment composer is visible
     connect(mainTimeline, SIGNAL(commentingOnPost(QWidget*)),
             this, SLOT(scrollMainTimelineToWidget(QWidget*)));
@@ -185,6 +214,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     directTimeline = new TimeLine(TimeLine::TimelineTypeDirect,
                                   pumpController,
+                                  globalObject,
                                   filterChecker,
                                   this);
     directTimelineScrollArea = new QScrollArea();
@@ -195,17 +225,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     directTimelineScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     connect(directTimeline, SIGNAL(scrollTo(QAbstractSlider::SliderAction)),
             this, SLOT(scrollDirectTimelineTo(QAbstractSlider::SliderAction)));
-    connect(directTimeline, SIGNAL(timelineRendered(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
-    connect(directTimeline, SIGNAL(unreadPostsCountChanged(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
+    connect(directTimeline, SIGNAL(timelineRendered(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
+    connect(directTimeline, SIGNAL(unreadPostsCountChanged(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
 
-    connect(directTimeline, SIGNAL(timelineRendered(int,int,int)),
+    connect(directTimeline, SIGNAL(timelineRendered(int,int,int,int)),
             this, SLOT(notifyTimelineUpdate(int,int,int)));
 
-    // direct timeline doesn't need a connection for post editing,
-    // since you're not gonna send a message to yourself =)
-
     // To ensure comment composer is visible
     connect(directTimeline, SIGNAL(commentingOnPost(QWidget*)),
             this, SLOT(scrollDirectTimelineToWidget(QWidget*)));
@@ -215,6 +242,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     activityTimeline = new TimeLine(TimeLine::TimelineTypeActivity,
                                     pumpController,
+                                    globalObject,
                                     filterChecker,
                                     this);
     activityTimelineScrollArea = new QScrollArea();
@@ -225,18 +253,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     activityTimelineScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     connect(activityTimeline, SIGNAL(scrollTo(QAbstractSlider::SliderAction)),
             this, SLOT(scrollActivityTimelineTo(QAbstractSlider::SliderAction)));
-    connect(activityTimeline, SIGNAL(timelineRendered(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
-    connect(activityTimeline, SIGNAL(unreadPostsCountChanged(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
+    connect(activityTimeline, SIGNAL(timelineRendered(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
+    connect(activityTimeline, SIGNAL(unreadPostsCountChanged(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
 
-    connect(activityTimeline, SIGNAL(timelineRendered(int,int,int)),
+    connect(activityTimeline, SIGNAL(timelineRendered(int,int,int,int)),
             this, SLOT(notifyTimelineUpdate(int,int,int)));
 
-    // for post editing
-    connect(activityTimeline, SIGNAL(postEditRequested(QString,QString,QString)),
-            publisher, SLOT(setEditingMode(QString,QString,QString)));
-
     // To ensure comment composer is visible
     connect(activityTimeline, SIGNAL(commentingOnPost(QWidget*)),
             this, SLOT(scrollActivityTimelineToWidget(QWidget*)));
@@ -246,6 +270,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     favoritesTimeline = new TimeLine(TimeLine::TimelineTypeFavorites,
                                      pumpController,
+                                     globalObject,
                                      filterChecker,
                                      this);
     favoritesTimelineScrollArea = new QScrollArea();
@@ -256,18 +281,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     favoritesTimelineScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     connect(favoritesTimeline, SIGNAL(scrollTo(QAbstractSlider::SliderAction)),
             this, SLOT(scrollFavoritesTimelineTo(QAbstractSlider::SliderAction)));
-    connect(favoritesTimeline, SIGNAL(timelineRendered(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
-    connect(favoritesTimeline, SIGNAL(unreadPostsCountChanged(int,int,int)),
-            this, SLOT(setTimelineTabTitle(int,int,int)));
+    connect(favoritesTimeline, SIGNAL(timelineRendered(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
+    connect(favoritesTimeline, SIGNAL(unreadPostsCountChanged(int,int,int,int)),
+            this, SLOT(setTimelineTabTitle(int,int,int,int)));
 
-    connect(favoritesTimeline, SIGNAL(timelineRendered(int,int,int)),
+    connect(favoritesTimeline, SIGNAL(timelineRendered(int,int,int,int)),
             this, SLOT(notifyTimelineUpdate(int,int,int)));
 
-    // for post editing
-    connect(favoritesTimeline, SIGNAL(postEditRequested(QString,QString,QString)),
-            publisher, SLOT(setEditingMode(QString,QString,QString)));
-
     // To ensure comment composer is visible
     connect(favoritesTimeline, SIGNAL(commentingOnPost(QWidget*)),
             this, SLOT(scrollFavoritesTimelineToWidget(QWidget*)));
@@ -277,30 +298,28 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
     // The contact list has its own tabs with its own scroll areas
-    contactManager = new ContactManager(pumpController, this);
+    contactManager = new ContactManager(pumpController,
+                                        globalObject,
+                                        this);
 
 
     tabWidget = new QTabWidget();
     tabWidget->addTab(mainTimelineScrollArea,
                       QIcon::fromTheme("view-list-details"),
                       "MAIN TIMELINE TAB");
-    tabWidget->setTabToolTip(0, tr("The main timeline"));
-    this->setTimelineTabTitle(TimeLine::TimelineTypeMain, 0, 0);
+    this->setTimelineTabTitle(TimeLine::TimelineTypeMain, 0, 0, 0);
     tabWidget->addTab(directTimelineScrollArea,
                       QIcon::fromTheme("mail-message"),
                       "MESSAGES TAB");
-    tabWidget->setTabToolTip(1, tr("Messages sent explicitly to you"));
-    this->setTimelineTabTitle(TimeLine::TimelineTypeDirect, 0, 0);
+    this->setTimelineTabTitle(TimeLine::TimelineTypeDirect, 0, 0, 0);
     tabWidget->addTab(activityTimelineScrollArea,
                       QIcon::fromTheme("user-home"),
                       "ACTIVITY TAB");
-    tabWidget->setTabToolTip(2, tr("Your own posts"));
-    this->setTimelineTabTitle(TimeLine::TimelineTypeActivity, 0, 0);
+    this->setTimelineTabTitle(TimeLine::TimelineTypeActivity, 0, 0, 0);
     tabWidget->addTab(favoritesTimelineScrollArea,
                       QIcon::fromTheme("folder-favorites"),
                       "FAVORITES TAB");
-    tabWidget->setTabToolTip(3, tr("Your favorited posts"));
-    this->setTimelineTabTitle(TimeLine::TimelineTypeFavorites, 0, 0);
+    this->setTimelineTabTitle(TimeLine::TimelineTypeFavorites, 0, 0, 0);
     tabWidget->addTab(contactManager,
                       QIcon::fromTheme("system-users"),
                       tr("&Contacts"));
@@ -323,8 +342,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     // FreeDesktop.org notifications handler
     fdNotifier = new FDNotifications();
-    connect(fdNotifier, SIGNAL(showFallbackNotification(QString)),
-            this, SLOT(showTrayFallbackMessage(QString)));
+    connect(fdNotifier, SIGNAL(showFallbackNotification(QString,QString)),
+            this, SLOT(showTrayFallbackMessage(QString,QString)));
 
 
     // Timeline updates timer
@@ -366,7 +385,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     }
 
     // Configuration dialog
-    configDialog = new ConfigDialog(this->dataDirectory,
+    configDialog = new ConfigDialog(this->globalObject,
+                                    this->dataDirectory,
                                     this->updateInterval,
                                     this->postsPerPageMain,
                                     this->postsPerPageOther,
@@ -381,6 +401,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     // Filter editor
     filterEditor = new FilterEditor(filterChecker, this);
+    connect(configDialog, SIGNAL(filterEditorRequested()),
+            filterEditor, SLOT(show()));
 
 
     // Log viewer
@@ -388,6 +410,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(pumpController, SIGNAL(logMessage(QString,QString)),
             logViewer, SLOT(addToLog(QString,QString)));
 
+
     // Help widget; "Getting started", etc.
     helpWidget = new HelpWidget(this);
 
@@ -411,14 +434,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
     // After receiving timeline contents, update corresponding timeline
-    connect(pumpController, SIGNAL(mainTimelineReceived(QVariantList,int,QString,QString)),
-            mainTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString)));
-    connect(pumpController, SIGNAL(directTimelineReceived(QVariantList,int,QString,QString)),
-            directTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString)));
-    connect(pumpController, SIGNAL(activityTimelineReceived(QVariantList,int,QString,QString)),
-            activityTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString)));
-    connect(pumpController, SIGNAL(favoritesTimelineReceived(QVariantList,int,QString,QString)),
-            favoritesTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString)));
+    connect(pumpController, SIGNAL(mainTimelineReceived(QVariantList,int,QString,QString,int)),
+            mainTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString,int)));
+    connect(pumpController, SIGNAL(directTimelineReceived(QVariantList,int,QString,QString,int)),
+            directTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString,int)));
+    connect(pumpController, SIGNAL(activityTimelineReceived(QVariantList,int,QString,QString,int)),
+            activityTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString,int)));
+    connect(pumpController, SIGNAL(favoritesTimelineReceived(QVariantList,int,QString,QString,int)),
+            favoritesTimeline, SLOT(setTimeLineContents(QVariantList,int,QString,QString,int)));
 
 
     // After sucessful posting, request updated timeline, with your post included
@@ -504,6 +527,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     if (!userID.isEmpty())
     {
         pumpController->setUserCredentials(this->userID);
+        fdNotifier->setCurrentUserId(this->userID);
         // getUserProfile() will be called from setUserCredentials()
     }
     else // Otherwise, just say so in the statusbar
@@ -807,7 +831,8 @@ void MainWindow::createMenus()
             filterEditor, SLOT(show()));
     settingsMenu->addAction(settingsFilters);
 
-    settingsConfigure = new QAction(QIcon::fromTheme("configure"),
+    settingsConfigure = new QAction(QIcon::fromTheme("configure",
+                                                     QIcon(":/images/button-configure.png")),
                                     tr("&Configure Dianara"), this);
     connect(settingsConfigure, SIGNAL(triggered()),
             configDialog, SLOT(show()));
@@ -1131,6 +1156,7 @@ void MainWindow::updateUserID(QString newUserID)
     this->setTitleAndTrayInfo(tabWidget->currentIndex());
 
     this->pumpController->setUserCredentials(userID);
+    this->fdNotifier->setCurrentUserId(userID);
 
     // Remove current user's name, id and avatar
     this->fullNameLabel->setText("--");
@@ -1335,9 +1361,9 @@ void MainWindow::trayControl(QSystemTrayIcon::ActivationReason reason)
  * fall back to Qt's balloon ones
  *
  */
-void MainWindow::showTrayFallbackMessage(QString message)
+void MainWindow::showTrayFallbackMessage(QString title, QString message)
 {
-    this->trayIcon->showMessage(tr("Dianara Activity"),
+    this->trayIcon->showMessage(title,
                                 message,
                                 QSystemTrayIcon::Information,
                                 4000); // 4 secs
@@ -1576,7 +1602,8 @@ void MainWindow::notifyTimelineUpdate(int timelineType,
  *
  */
 void MainWindow::setTimelineTabTitle(int timelineType,
-                                     int newPostCount, int highlightCount)
+                                     int newPostCount, int highlightCount,
+                                     int totalItemsCount)
 {
     int updatedTab = 0;
 
@@ -1591,29 +1618,35 @@ void MainWindow::setTimelineTabTitle(int timelineType,
     }
 
 
+    QString totalItemsString = "\n\n" + tr("Total posts: %1").arg(totalItemsCount);
+
     switch (timelineType)
     {
     case TimeLine::TimelineTypeMain:
-        this->tabWidget->setTabText(0,
-                                    tr("&Timeline") + messageCountString);
+        this->tabWidget->setTabText(0, tr("&Timeline") + messageCountString);
+        this->tabWidget->setTabToolTip(0, tr("The main timeline")
+                                          + totalItemsString);
         updatedTab = 0;
         break;
 
     case TimeLine::TimelineTypeDirect:
-        this->tabWidget->setTabText(1,
-                                    tr("&Messages") + messageCountString);
+        this->tabWidget->setTabText(1, tr("&Messages") + messageCountString);
+        this->tabWidget->setTabToolTip(1, tr("Messages sent explicitly to you")
+                                          + totalItemsString);
         updatedTab = 1;
         break;
 
     case TimeLine::TimelineTypeActivity:
-        this->tabWidget->setTabText(2,
-                                    tr("&Activity") + messageCountString);
+        this->tabWidget->setTabText(2, tr("&Activity") + messageCountString);
+        this->tabWidget->setTabToolTip(2, tr("Your own posts")
+                                          + totalItemsString);
         updatedTab = 2;
         break;
 
     case TimeLine::TimelineTypeFavorites:
-        this->tabWidget->setTabText(3,
-                                    tr("Favor&ites") + messageCountString);
+        this->tabWidget->setTabText(3, tr("Favor&ites") + messageCountString);
+        this->tabWidget->setTabToolTip(3, tr("Your favorited posts")
+                                          + totalItemsString);
         updatedTab = 3;
         break;
     }
@@ -1684,15 +1717,19 @@ void MainWindow::setTitleAndTrayInfo(int currentTab)
  * Set the title for the minor feed (Meanwhile), with new item count
  *
  */
-void MainWindow::setMinorFeedTitle(int newItemsCount)
+void MainWindow::setMinorFeedTitle(int newItemsCount,
+                                   int newHighlightedItemsCount)
 {
     QString title = tr("Meanwhile...");
     if (newItemsCount > 0)
     {
         title.append(QString(" (%1)").arg(newItemsCount));
+        if (newHighlightedItemsCount > 0)
+        {
+            title.append(QString(" [%1]").arg(newHighlightedItemsCount));
+        }
     }
 
-
     this->leftPanel->setItemText(0, title);
 }
 
@@ -1871,7 +1908,7 @@ void MainWindow::markAllAsRead()
     favoritesTimeline->markPostsAsRead();
 
     meanwhileFeed->markAllAsRead();
-    this->setMinorFeedTitle(0);
+    this->setMinorFeedTitle(0, 0);
 }
 
 
@@ -2076,7 +2113,7 @@ void MainWindow::visitUserList()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v1.2.2</b><br>"
+                       "<b>Dianara v1.2.3</b><br>"
                        "Copyright 2012-2014  JanKusanagi<br><br>"
                        "<a href=\"http://jancoding.wordpress.com/dianara\">"
                        "http://jancoding.wordpress.com/dianara</a><br><br>"
