@@ -67,6 +67,9 @@
 #include "filterchecker.h"
 #include "logviewer.h"
 #include "helpwidget.h"
+#include "groupsmanager.h"
+
+#include "globalobject.h"
 
 
 class MainWindow : public QMainWindow
@@ -98,7 +101,7 @@ public slots:
     void postInit();
 
     void trayControl(QSystemTrayIcon::ActivationReason reason);
-    void showTrayFallbackMessage(QString message);
+    void showTrayFallbackMessage(QString title, QString message);
 
     void updateProfileData(QString avatarUrl, QString fullName,
                            QString hometown, QString bio,
@@ -123,10 +126,11 @@ public slots:
                               int highlightCount);
     void setTimelineTabTitle(int timelineType,
                              int newPostCount,
-                             int highlightCount);
+                             int highlightCount,
+                             int totalItemsCount);
 
     void setTitleAndTrayInfo(int currentTab);
-    void setMinorFeedTitle(int newItemsCount);
+    void setMinorFeedTitle(int newItemsCount, int newHighlightedItemsCount);
     void notifyMinorFeedUpdate(int newItemsCount, int highlightedCount);
 
     void storeAvatar(QByteArray avatarData, QUrl avatarUrl);
@@ -241,6 +245,7 @@ private:
     int trayCurrentCount;
 
 
+    GlobalObject *globalObject;
 
     AccountDialog *accountDialog;
     ProfileEditor *profileEditor;
