@@ -22,10 +22,12 @@
 
 
 MinorFeed::MinorFeed(PumpController *pumpController,
+                     GlobalObject *globalObject,
                      FilterChecker *filterChecker,
                      QWidget *parent) : QFrame(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
     this->fChecker = filterChecker;
     this->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
 
@@ -81,7 +83,8 @@ MinorFeed::MinorFeed(PumpController *pumpController,
     MinorFeedItem *demoFeedItem = new MinorFeedItem(demoActivity,
                                                     this->highlightColorsList,
                                                     false, // Not highlighted by filter
-                                                    this->pController);
+                                                    this->pController,
+                                                    this->globalObj);
     this->itemsLayout->addWidget(demoFeedItem);
     this->itemsInFeed.append(demoFeedItem);
 
@@ -272,12 +275,13 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
             MinorFeedItem *newFeedItem = new MinorFeedItem(activity,
                                                            this->highlightColorsList,
                                                            itemHighlightedByFilter,
-                                                           this->pController);
+                                                           this->pController,
+                                                           this->globalObj);
+            newFeedItem->setItemAsNew(itemIsNew);
             if (itemIsNew)
             {
-                newFeedItem->setItemAsNew(true);
-                connect(newFeedItem, SIGNAL(itemRead()),
-                        this, SLOT(decreaseNewItemsCount()));
+                connect(newFeedItem, SIGNAL(itemRead(bool)),
+                        this, SLOT(decreaseNewItemsCount(bool)));
 
                 if (newFeedItem->getItemHighlightType() != -1)
                 {
@@ -296,7 +300,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 
 
     this->previousNewestActivityId = newestActivityId;
-    emit newItemsCountChanged(newItemsCount);
+    emit newItemsCountChanged(newItemsCount, newHighlightedItemsCount);
     emit newItemsReceived(newItemsCount, newHighlightedItemsCount);
     qDebug() << "Meanwhile feed updated; New items:" << newItemsCount;
 
@@ -305,9 +309,13 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 }
 
 
-void MinorFeed::decreaseNewItemsCount()
+void MinorFeed::decreaseNewItemsCount(bool wasHighlighted)
 {
     --newItemsCount;
+    if (wasHighlighted)
+    {
+        --newHighlightedItemsCount;
+    }
 
-    emit newItemsCountChanged(newItemsCount);
+    emit newItemsCountChanged(newItemsCount, newHighlightedItemsCount);
 }
