@@ -30,6 +30,7 @@
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "mischelpers.h"
 #include "minorfeeditem.h"
 #include "asactivity.h"
@@ -42,6 +43,7 @@ class MinorFeed : public QFrame
 
 public:
     explicit MinorFeed(PumpController *pumpController,
+                       GlobalObject *globalObject,
                        FilterChecker *filterChecker,
                        QWidget *parent = 0);
     ~MinorFeed();
@@ -51,17 +53,19 @@ public:
     void markAllAsRead();
     void updateFuzzyTimestamps();
 
+
 signals:
-    void newItemsCountChanged(int itemCount);
+    void newItemsCountChanged(int itemCount, int highlightedCount);
     void newItemsReceived(int itemCount, int highlightedCount);
 
+
 public slots:
     void updateFeed();
     void getMoreActivities();
     void setFeedContents(QVariantList activitiesList,
                          QString previous, QString next);
 
-    void decreaseNewItemsCount();
+    void decreaseNewItemsCount(bool wasHighlighted);
 
 
 private:
@@ -85,6 +89,7 @@ private:
     QStringList highlightColorsList;
 
     PumpController *pController;
+    GlobalObject *globalObj;
     FilterChecker *fChecker;
 };
 
