@@ -25,16 +25,18 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
                              QStringList highlightColors,
                              bool highlightedByFilter,
                              PumpController *pumpController,
+                             GlobalObject *globalObject,
                              QWidget *parent) : QFrame(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
 
     this->itemIsNew = false;
 
     // This sizePolicy prevents cut messages, and the huge space at the end
-    // of the feed, after clicking "More" several times
+    // of the feed, after clicking "Older Activities" several times
     this->setSizePolicy(QSizePolicy::Minimum,
-                        QSizePolicy::MinimumExpanding);
+                        QSizePolicy::Preferred);
 
     activity->setParent(this); // reparent the passed activity
 
@@ -45,7 +47,9 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     avatarButton = new AvatarButton(activity->author(),
                                     this->pController,
-                                    QSize(32,32));
+                                    this->globalObj,
+                                    QSize(32,32),
+                                    this);
 
 
     createdAtTimestamp = activity->getCreatedAt();
@@ -190,25 +194,34 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
 
     activityDescriptionLabel = new QLabel(activity->getContent());
-    mainFont.setBold(false);
-    activityDescriptionLabel->setFont(mainFont);
+                                          // + " &nbsp;");  // FIXME 1.2.4?
+                                          // + " <br>");
+    QFont descriptionFont;
+    descriptionFont.fromString(globalObj->getMinorFeedFont());
+    activityDescriptionLabel->setFont(descriptionFont);
     activityDescriptionLabel->setWordWrap(true);
     activityDescriptionLabel->setOpenExternalLinks(true);
+    activityDescriptionLabel->setAlignment(Qt::AlignTop);
+    activityDescriptionLabel->setSizePolicy(QSizePolicy::Ignored,
+                                            QSizePolicy::MinimumExpanding);
     connect(activityDescriptionLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(showUrlInfo(QString)));
 
-    // Set the activity info as tooltip for the whole widget, not only the label
-    this->setToolTip(activityTooltip);
+    if (!activityTooltip.isEmpty())
+    {
+        // Set the activity info as tooltip for the whole widget, not only the label
+        this->setToolTip(activityTooltip);
+
+        // Set a different mouse cursor for the description label, as a hint to wait for tooltip info
+        this->activityDescriptionLabel->setCursor(Qt::WhatsThisCursor);
+    }
 
 
     originalObjectMap = activity->object()->getOriginalObject();
 
     inReplyToMap = activity->object()->getInReplyTo();
-    QString inReplyToAuthor = inReplyToMap.value("author").toMap().value("id").toString();
-    if (inReplyToAuthor.startsWith("acct:"))
-    {
-        inReplyToAuthor.remove(0,5);
-    }
+    QString inReplyToAuthorId = ASPerson::cleanupId(inReplyToMap.value("author").toMap()
+                                                                .value("id").toString());
 
 
 
@@ -228,7 +241,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     }
 
     // Activity is in reply to something made by us
-    if (inReplyToAuthor == pController->currentUserId())
+    if (inReplyToAuthorId == pController->currentUserId())
     {
         itemHighlightType = 1;
 
@@ -305,14 +318,26 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     leftLayout->setAlignment(Qt::AlignTop);
     leftLayout->addWidget(avatarButton, 1, Qt::AlignTop | Qt::AlignLeft);
 
+
+    bool canDisplayObject = false;
+    QString activityObjectType = activity->object()->getType();
+    if (activityObjectType == "note"
+     || activityObjectType == "article"
+     || activityObjectType == "image"
+     || activityObjectType == "audio"
+     || activityObjectType == "video"
+     || activityObjectType == "file"
+     || activityObjectType == "comment"
+     || activityObjectType == "group")
+    {
+        canDisplayObject = true;
+    }
+
     // Original post available (inReplyTo) or object available (note, image...)
     if (!inReplyToMap.isEmpty()
-      || ( (activity->object()->getType() == "note"
-            || activity->object()->getType() == "image"
-            || activity->object()->getType() == "audio"
-            || activity->object()->getType() == "video"
-            || activity->object()->getType() == "file")
-          && activity->object()->getDeletedTime().isEmpty() ) )
+        || (canDisplayObject
+            && activity->object()->getDeletedTime().isEmpty())
+       )
     {
         this->openButton = new QPushButton("+");
         openButton->setSizePolicy(QSizePolicy::Ignored,
@@ -341,8 +366,10 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
         if (personObject->getId() != authorId) // avoid cases like "JohnDoe updated JohnDoe"
         {
             AvatarButton *targetAvatar = new AvatarButton(personObject,
-                                                          pController,
-                                                          QSize(28,28));
+                                                          this->pController,
+                                                          this->globalObj,
+                                                          QSize(28,28),
+                                                          this);
             rightLowerLayout->addWidget(targetAvatar, 0, Qt::AlignBottom);
         }
     }
@@ -385,22 +412,33 @@ void MinorFeedItem::setItemAsNew(bool isNew)
         this->setAutoFillBackground(true);
         this->setBackgroundRole(QPalette::Mid);
 
-        this->timestampLabel->setForegroundRole(QPalette::HighlightedText);
-        this->timestampLabel->setBackgroundRole(QPalette::Highlight);
+        timestampLabel->setStyleSheet("QLabel "
+                                      "{ color: palette(highlighted-text);   "
+                                      "  background-color: palette(highlight)"
+                                      "}"
+                                      "QLabel:hover "
+                                      "{ color: palette(text);               "
+                                      "  background-color: palette(highlight)"
+                                      "}");
     }
     else
     {
         this->setAutoFillBackground(false);
         this->setBackgroundRole(QPalette::Window);
 
-        this->timestampLabel->setForegroundRole(QPalette::Text);
-        this->timestampLabel->setBackgroundRole(QPalette::Base);
-
-        emit itemRead();
+        timestampLabel->setStyleSheet("QLabel:hover "
+                                      "{ background-color: palette(highlight) }");
+        bool wasHighlighted = false;
+        if (this->itemHighlightType != -1)
+        {
+            wasHighlighted = true;
+        }
+        emit itemRead(wasHighlighted);
     }
 
     // Avoid possible flickering of the "new" effect later
     this->timestampLabel->update();
+    this->update();
 }
 
 
@@ -454,10 +492,9 @@ void MinorFeedItem::openOriginalPost()
                                     false, // Not highlighted
                                     true,  // Post is standalone
                                     pController,
+                                    globalObj,
                                     this->parentWidget()); // Pass parent widget (MinorFeed) instead
                                                            // of 'this', so it won't be killed by reloads
-    referencedPost->setWindowFlags(Qt::Window);
-    referencedPost->setWindowModality(Qt::WindowModal);
     referencedPost->show();
     connect(pController, SIGNAL(commentsReceived(QVariantList,QString)),
             referencedPost, SLOT(setAllComments(QVariantList,QString)));
