@@ -32,6 +32,7 @@
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "timestamp.h"
 #include "asactivity.h"
 #include "post.h"
@@ -47,6 +48,7 @@ public:
                            QStringList highlightColors,
                            bool highlightedByFilter,
                            PumpController *pumpController,
+                           GlobalObject *globalObject,
                            QWidget *parent = 0);
     ~MinorFeedItem();
 
@@ -56,7 +58,7 @@ public:
     int getItemHighlightType();
     
 signals:
-    void itemRead();
+    void itemRead(bool wasHighlighted);
 
     
 public slots:
@@ -69,6 +71,7 @@ protected:
 
 private:
     PumpController *pController;
+    GlobalObject *globalObj;
 
     QHBoxLayout *mainLayout;
     QVBoxLayout *leftLayout;
