@@ -119,6 +119,7 @@ QString MiscHelpers::getSuggestedFilename(QString authorId,
     suggestedFilename.remove("*");
     suggestedFilename.remove(":");
     suggestedFilename.remove(";");
+    suggestedFilename.remove("\"");
 
     suggestedFilename.replace(" ", "_"); // Avoid spaces in filename
 
@@ -368,11 +369,15 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
         pos += linkStyleRE.matchedLength() - removedTextOffset;
     }
 
-    /////////////////////////////////////////// Remove style from <ul> and <li>
+    ////////////////////////////////////// Remove style from <ul> <ol> and <li>
     QRegExp ulStyleRE("<ul style.*>");
     ulStyleRE.setMinimal(true);
     cleanHtml.replace(ulStyleRE, "<ul>");
 
+    QRegExp olStyleRE("<ol style.*>");
+    olStyleRE.setMinimal(true);
+    cleanHtml.replace(olStyleRE, "<ol>");
+
     QRegExp liStyleRE("<li style.*>");
     liStyleRE.setMinimal(true);
     cleanHtml.replace(liStyleRE, "<li>");
@@ -385,6 +390,25 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
     return cleanHtml.trimmed();
 }
 
+/*
+ * Remove only <a href...> and </a> from a HTML text
+ *
+ */
+QString MiscHelpers::htmlWithoutLinks(QString originalHtml)
+{
+    QString cleanHtml = originalHtml;
+
+    QRegExp linksRE("<a href=.*>");
+    linksRE.setMinimal(true);
+    linksRE.setCaseSensitivity(Qt::CaseInsensitive);
+    cleanHtml.remove(linksRE);
+
+    cleanHtml.remove("</a>", Qt::CaseInsensitive);
+
+
+    return cleanHtml;
+}
+
 
 
 /*
