@@ -86,6 +86,11 @@ void FDNotifications::setNotificationOptions(int style,
              << this->notifyNewMeanwhile << this->notifyHLMeanwhile;
 }
 
+void FDNotifications::setCurrentUserId(QString newId)
+{
+    this->currentUserId = newId;
+}
+
 
 bool FDNotifications::getNotifyNewTimeline()
 {
@@ -118,17 +123,19 @@ bool FDNotifications::getNotifyHLMeanwhile()
 void FDNotifications::showMessage(QString message)
 {
     // if notifications are disabled
-    if (notificationType == FDNotifications::NoNotifications)
+    if (this->notificationType == FDNotifications::NoNotifications)
     {
         return;
     }
 
+    QString notificationTitle = "Dianara - " + currentUserId;
 
     // If FD.org notifications are not available, or Qt's Balloon ones are selected
     if (!notificationsAvailable
        || notificationType == FDNotifications::FallbackNotifications)
     {
-        qDebug() << "FreeDesktop Notifications are NOT available, or balloon notifications selected";
+        qDebug() << "FreeDesktop Notifications are NOT available, "
+                    "or balloon notifications selected";
 
         // Clean up possible HTML, since Qt's balloons don't support it
         message.remove("<b>");
@@ -138,7 +145,7 @@ void FDNotifications::showMessage(QString message)
         message.remove("<u>");
         message.remove("</u>");
         // FIXME: remove also <a href=...>
-        emit showFallbackNotification(message);
+        emit showFallbackNotification(notificationTitle, message);
 
         return;
     }
@@ -169,7 +176,7 @@ void FDNotifications::showMessage(QString message)
     {
         arguments << QString("dialog-information");   // app_icon otherwise
     }
-    arguments << QString(tr("Dianara Activity"));
+    arguments << notificationTitle;
     arguments << message;
     arguments << QStringList();        // actions
     arguments << QVariantMap();        // hints
