@@ -43,6 +43,8 @@ public:
                                 bool notifyHLTL,
                                 bool notifyNewMW,
                                 bool notifyHLMW);
+    void setCurrentUserId(QString newId);
+
     bool getNotifyNewTimeline();
     bool getNotifyHLTimeline();
     bool getNotifyNewMeanwhile();
@@ -58,7 +60,7 @@ public:
 
 
 signals:
-    void showFallbackNotification(QString message);
+    void showFallbackNotification(QString title, QString message);
 
 
 public slots:
@@ -75,6 +77,8 @@ private:
     bool notifyHLTimeline;
     bool notifyNewMeanwhile;
     bool notifyHLMeanwhile;
+
+    QString currentUserId;
 };
 
 #endif // NOTIFICATIONS_H
