@@ -25,15 +25,19 @@ Post::Post(ASActivity *activity,
            bool highlightedByFilter,
            bool isStandalone,
            PumpController *pumpController,
+           GlobalObject *globalObject,
            QWidget *parent)  :  QFrame(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
     this->standalone = isStandalone;
+
     this->seeFullImageString = tr("Click the image to see it in full size");
     this->downloadAttachmentString = tr("Click to download the attachment");
     this->postImageIsAnimated = false; // Initialize
     this->setSizePolicy(QSizePolicy::MinimumExpanding,
                         QSizePolicy::Minimum);
+    this->setMinimumSize(10, 10); // Ensure something's visible at all times
 
     activity->setParent(this); // reparent the passed activity
 
@@ -115,6 +119,10 @@ Post::Post(ASActivity *activity,
     {
         postTypeString = tr("File");
     }
+    else if (postType == "group")
+    {
+        postTypeString = tr("Group");
+    }
     else if (postType == "comment")
     {
         postTypeString = tr("Comment",
@@ -123,7 +131,8 @@ Post::Post(ASActivity *activity,
     else
     {
         postTypeString = tr("Other",
-                            "As in: other type of post");
+                            "As in: other type of post")
+                         + " (" + postType + ")";
     }
 
     this->postUrl = activity->object()->getUrl();
@@ -161,6 +170,8 @@ Post::Post(ASActivity *activity,
         QString windowTitle = tr("Post", "Noun, not verb")
                               + ": " + postTypeString + " - Dianara";
         this->setWindowTitle(windowTitle);
+        this->setWindowFlags(Qt::Window);
+        this->setWindowModality(Qt::WindowModal);
 
         // Restore size
         this->setMinimumSize(420, 360);
@@ -237,7 +248,9 @@ Post::Post(ASActivity *activity,
     // Author avatar
     postAuthorAvatarButton = new AvatarButton(authorPerson,
                                               this->pController,
-                                              QSize(48, 48));
+                                              this->globalObj,
+                                              QSize(48, 48),
+                                              this);
 
     ///////////// Add extra options to the avatar menu
     postAuthorAvatarButton->addSeparatorToMenu();
@@ -340,17 +353,19 @@ Post::Post(ASActivity *activity,
     postCreatedAtLabel->setWordWrap(true);
     postCreatedAtLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postCreatedAtLabel->setFont(detailsFont);
+    postCreatedAtLabel->setAutoFillBackground(true);
     leftColumnLayout->addWidget(postCreatedAtLabel);
     leftColumnLayout->addSpacing(4);
 
     // Location information, if any
-    QString location = activity->object()->getLocation();
+    QString location = activity->object()->getLocationName();
     if (!location.isEmpty())
     {
         this->postLocationLabel = new QLabel(tr("In")
                                              + ": <b>" + location + "</b>");
         postLocationLabel->setWordWrap(true);
         postLocationLabel->setFont(detailsFont);
+        postLocationLabel->setToolTip(activity->object()->getLocationTooltip());
         leftColumnLayout->addWidget(postLocationLabel);
         leftColumnLayout->addSpacing(2);
     }
@@ -422,11 +437,37 @@ Post::Post(ASActivity *activity,
     this->setSharesLabel(sharesCount);
 
 
+
     // Try to use all remaining space, aligning
     // all previous widgets nicely at the top
     // leftColumnLayout->setAlignment(Qt::AlignTop) caused glitches
     leftColumnLayout->addStretch(1);
 
+    QFont buttonsFont;
+    buttonsFont.setPointSize(buttonsFont.pointSize() - 1);
+
+
+    // Check if the object is in reply to something (a shared comment, for instance)
+    this->postParentMap = activity->object()->getInReplyTo();
+    if (!postParentMap.isEmpty())
+    {
+        openParentPostButton = new QPushButton(QIcon::fromTheme("go-up-search",
+                                                                QIcon(":/images/button-parent.png")),
+                                               tr("Parent",
+                                                  "As in 'Open the parent post'. "
+                                                  "Try to use the shortest word!"));
+        //openParentPostButton->setFlat(true);
+        openParentPostButton->setFont(buttonsFont);
+        openParentPostButton->setSizePolicy(QSizePolicy::Ignored,
+                                            QSizePolicy::Maximum);
+        openParentPostButton->setToolTip(tr("Open the parent post, to which "
+                                            "this one replies"));
+        connect(openParentPostButton, SIGNAL(clicked()),
+                this, SLOT(openParentPost()));
+        leftColumnLayout->addWidget(openParentPostButton);
+    }
+
+
     leftColumnFrame->setLayout(leftColumnLayout);
 
 
@@ -446,13 +487,24 @@ Post::Post(ASActivity *activity,
         this->postTitleLabel = new QLabel();
         postTitleLabel->setWordWrap(true);
         QFont postTitleFont;
-        postTitleFont.setBold(true);
-        postTitleFont.setPointSize(postTitleFont.pointSize() + 1);
+        postTitleFont.fromString(globalObj->getPostTitleFont());
         postTitleLabel->setFont(postTitleFont);
         postTitleLabel->setText(postTitle);
         rightColumnLayout->addWidget(postTitleLabel, 0);
     }
 
+    ///////////////////////////////////// Summary
+    QString postSummary = activity->object()->getSummary();
+    if (!postSummary.isEmpty())
+    {
+        this->postSummaryLabel = new QLabel();
+        postSummaryLabel->setWordWrap(true);
+        postSummaryLabel->setFont(detailsFont);
+        postSummaryLabel->setText(postSummary);
+        rightColumnLayout->addWidget(postSummaryLabel, 0);
+    }
+
+
     ///////////////////////////////////// Post text
     postText = new QTextBrowser();
     postText->setAlignment(Qt::AlignLeft | Qt::AlignTop);
@@ -462,6 +514,11 @@ Post::Post(ASActivity *activity,
     postText->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     postText->setOpenLinks(false); // don't open links, manage in openClickedURL()
     postText->setReadOnly(true); // it's default with QTextBrowser, but still...
+
+    QFont postContentsFont;
+    postContentsFont.fromString(globalObj->getPostContentsFont());
+    postText->setFont(postContentsFont);
+
     // To help screen readers, enable keyboard interaction here
     // This is disabled for now, since it doesn't really help; hopefully with Qt5
     // things will be better.
@@ -482,8 +539,6 @@ Post::Post(ASActivity *activity,
     buttonsLayout->setMargin(0);
     buttonsLayout->setSpacing(0);
 
-    QFont buttonsFont;
-    buttonsFont.setPointSize(buttonsFont.pointSize() - 1);
 
     // Like button
     likeButton = new QPushButton(QIcon::fromTheme("emblem-favorite",
@@ -626,6 +681,24 @@ Post::Post(ASActivity *activity,
     this->getPendingImages();
 
 
+    // Button to join/leave the group, if the post is the creation of a group
+    if (postType == "group") // FIXME: for now, only JOIN, as we can't know if we're members yet
+    {
+        this->joinLeaveButton = new QPushButton(QIcon::fromTheme("user-group-new"),
+                                                tr("Join Group"));
+        connect(joinLeaveButton, SIGNAL(clicked()),
+                this, SLOT(joinGroup()));
+        rightColumnLayout->addWidget(joinLeaveButton, 0, Qt::AlignCenter);
+
+        this->groupInfoLabel = new QLabel(tr("%1 members in the group")
+                                          .arg(activity->object()->getMemberCount()));
+        groupInfoLabel->setWordWrap(true);
+        groupInfoLabel->setFont(detailsFont);
+        groupInfoLabel->setAlignment(Qt::AlignCenter);
+        rightColumnLayout->addWidget(groupInfoLabel);
+    }
+
+
     // Widget to download the attached media, if any
     if (!attachmentUrl.isEmpty())
     {
@@ -651,7 +724,9 @@ Post::Post(ASActivity *activity,
 
 
     /////////////////////////////////////////////////////// Comments block
-    this->commenter = new CommenterBlock(this->pController);
+    this->commenter = new CommenterBlock(this->pController,
+                                         this->globalObj,
+                                         this);
     connect(commenter, SIGNAL(commentSent(QString)),
             this, SLOT(sendComment(QString)));
     connect(commenter, SIGNAL(commentUpdated(QString,QString)),
@@ -752,7 +827,7 @@ void Post::setPostContents()
         }
         else // use placeholder image while it loads...
         {
-            const QString imageLoadingString = tr("Image is loading...");
+            const QString imageLoadingString = tr("Loading image...");
             postMediaHtml = "<br>"
                             "<div align=center "
                             "title=\"" + imageLoadingString + "\">"
@@ -1118,15 +1193,20 @@ void Post::setPostUnreadStatus()
 
     if (this->postIsUnread)
     {
-        postCreatedAtLabel->setAutoFillBackground(true);
-        postCreatedAtLabel->setForegroundRole(QPalette::HighlightedText);
-        postCreatedAtLabel->setBackgroundRole(QPalette::Highlight);
+        postCreatedAtLabel->setStyleSheet("QLabel "
+                                          "{ color: palette(highlighted-text);   "
+                                          "  background-color: palette(highlight)"
+                                          "}"
+                                          "QLabel:hover "
+                                          "{ color: palette(text);               "
+                                          "  background-color: palette(highlight)"
+                                          "}");
 
         if (!css.isEmpty())
         {
             rightColumnFrame->setStyleSheet(css);
         }
-        else
+        else // Unused at the moment, but could be an option to avoid gradients
         {
             this->setAutoFillBackground(true);
             this->setBackgroundRole(QPalette::Mid);
@@ -1134,19 +1214,20 @@ void Post::setPostUnreadStatus()
     }
     else
     {
+        postCreatedAtLabel->setStyleSheet("QLabel "
+                                          "{ background-color: transparent }"
+                                          "QLabel:hover "
+                                          "{ background-color: palette(highlight) }");
+
         rightColumnFrame->setStyleSheet("");
 
-        postCreatedAtLabel->setAutoFillBackground(false);
-        postCreatedAtLabel->setForegroundRole(QPalette::WindowText);
-        postCreatedAtLabel->setBackgroundRole(QPalette::Window);
-
-        this->setAutoFillBackground(false);
+        this->setAutoFillBackground(true);
         this->setBackgroundRole(QPalette::Window);
     }
 
     // Avoid possible later flickering of the "new" effect
-    this->postAuthorNameLabel->update();
     this->postCreatedAtLabel->update();
+    this->update();
 }
 
 
@@ -1162,7 +1243,17 @@ void Post::setPostAsRead()
     if (postIsUnread)
     {
         this->postIsUnread = false;
-        emit postRead(); // Inform the Timeline()
+
+        // Inform the Timeline()
+        if (this->highlightType == NoHighlight)
+        {
+            emit postRead(false);
+        }
+        else
+        {
+            emit postRead(true); // Say it's marked as read, and was highlighted
+        }
+
 
         setPostUnreadStatus();
     }
@@ -1366,9 +1457,13 @@ void Post::unsharePost()
  */
 void Post::editPost()
 {
-    emit postEditRequested(this->postId,
-                           this->postOriginalText,
-                           this->postTitle);
+    this->globalObj->editPost(this->postId,
+                              this->postTitle,
+                              this->postOriginalText);
+    if (standalone)
+    {
+        this->close();
+    }
 }
 
 
@@ -1397,6 +1492,15 @@ void Post::deletePost()
 }
 
 
+void Post::joinGroup()
+{
+    qDebug() << "Joining group " << this->postId << "via Post() button";
+    this->pController->joinGroup(this->postId);
+
+    this->joinLeaveButton->setDisabled(true); // FIXME; make it turn into "Leave", etc.
+}
+
+
 
 void Post::openClickedURL(QUrl url)
 {
@@ -1465,6 +1569,36 @@ void Post::copyPostUrlToClipboard()
     QApplication::clipboard()->setText(this->postUrl);
 }
 
+void Post::openParentPost()
+{
+    qDebug() << "Opening parent post...";
+
+    // Create a fake activity for the parent post
+    QVariantMap fakeActivityMap;
+    fakeActivityMap.insert("object", this->postParentMap);
+    fakeActivityMap.insert("actor",  this->postParentMap.value("author").toMap());
+
+    ASActivity *originalPostActivity = new ASActivity(fakeActivityMap, this);
+
+    QStringList colorsList;
+    colorsList << "" << "" << ""
+               << "" << "" << ""; // Empty color list, needs 6 colors to avoid crashes
+
+    Post *parentPost = new Post(originalPostActivity,
+                                colorsList,
+                                false, // Not highlighted
+                                true,  // Post is standalone
+                                pController,
+                                globalObj,
+                                this->parentWidget()); // Pass parent widget (Timeline or
+                                                       // another Post) instead of
+                                                       // 'this', so it won't be killed by reloads
+    parentPost->show();
+    connect(pController, SIGNAL(commentsReceived(QVariantList,QString)),
+            parentPost, SLOT(setAllComments(QVariantList,QString)));
+    parentPost->getAllComments();
+}
+
 
 /*
  * Normalize text colors; Used from menu when a post
