@@ -43,9 +43,10 @@
 #include <QDebug>
 
 
+#include "pumpcontroller.h"
+#include "globalobject.h"
 #include "timestamp.h"
 #include "mischelpers.h"
-#include "pumpcontroller.h"
 #include "commenterblock.h"
 #include "imageviewer.h"
 #include "asactivity.h"
@@ -63,6 +64,7 @@ public:
          bool highlightedByFilter,
          bool isStandalone,
          PumpController *pumpController,
+         GlobalObject *globalObject,
          QWidget *parent);
     ~Post();
 
@@ -104,10 +106,7 @@ public:
 
 
 signals:
-    void postRead();
-    void postEditRequested(QString originalPostID,
-                           QString contents,
-                           QString title);
+    void postRead(bool wasHighlighted);
     void commentingOnPost(QWidget *commenterWidget);
 
 
@@ -131,12 +130,15 @@ public slots:
 
     void deletePost();
 
+    void joinGroup();
+
     void openClickedURL(QUrl url);
     void showHighlightedUrl(QString url);
 
 
     void openPostInBrowser();
     void copyPostUrlToClipboard();
+    void openParentPost();
     void normalizeTextFormat();
 
     void triggerResize();
@@ -192,8 +194,11 @@ private:
     QLabel *postCommentsCountLabel;
     QLabel *postResharesCountLabel;
 
+    QPushButton *openParentPostButton;
+
 
     QLabel *postTitleLabel;
+    QLabel *postSummaryLabel;
     QTextBrowser *postText;
 
     QHBoxLayout *buttonsLayout;
@@ -204,6 +209,9 @@ private:
     QPushButton *editButton;
     QPushButton *deleteButton;
 
+    QPushButton *joinLeaveButton;
+    QLabel *groupInfoLabel;
+
     DownloadWidget *downloadWidget;
 
     QString postTitle;
@@ -215,6 +223,7 @@ private:
     QString postFileMimeType;
     QString postAttachmentPureUrl;
     QString postOriginalText;
+    QVariantMap postParentMap;
 
     QString postCreatedAtString;
     QString postUpdatedAtString;
@@ -236,6 +245,7 @@ private:
     QString downloadAttachmentString;
 
     PumpController *pController;
+    GlobalObject *globalObj;
     CommenterBlock *commenter;
 };
 
