@@ -50,7 +50,8 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
 
     avatarLabel = new QLabel();
-    avatarLabel->setPixmap(QIcon::fromTheme("user-properties").pixmap(64, 64));
+    avatarLabel->setPixmap(QIcon::fromTheme("user-properties",
+                                            QIcon(":/images/no-avatar.png")).pixmap(64, 64));
 
     changeAvatarButton = new QPushButton(QIcon::fromTheme("folder-image-people"),
                                          tr("Change &Avatar..."));
@@ -70,11 +71,13 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
 
 
-    saveButton = new QPushButton(QIcon::fromTheme("document-save"),
+    saveButton = new QPushButton(QIcon::fromTheme("document-save",
+                                                  QIcon(":/images/button-save.png")),
                                  tr("&Save Profile"));
     connect(saveButton, SIGNAL(clicked()), this, SLOT(saveProfile()));
 
-    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel"),
+    cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                    QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"));
     connect(cancelButton, SIGNAL(clicked()), this, SLOT(hide()));
 
@@ -114,6 +117,8 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
+    // Disable some stuff until profile is received
+    this->toggleWidgetsEnabled(false);
 
     qDebug() << "ProfileEditor created";
 }
@@ -160,6 +165,24 @@ void ProfileEditor::setProfileData(QString avatarUrl, QString fullName,
     this->fullNameLineEdit->setText(fullName);
     this->hometownLineEdit->setText(hometown);
     this->bioTextEdit->setText(bio);
+
+    // Enable all widgets, since the profile is valid now
+    this->toggleWidgetsEnabled(true);
+}
+
+/*
+ * Enable or disable some widgets depending on whether the profile has been received
+ *
+ */
+void ProfileEditor::toggleWidgetsEnabled(bool state)
+{
+    this->changeAvatarButton->setEnabled(state);
+
+    this->fullNameLineEdit->setEnabled(state);
+    this->hometownLineEdit->setEnabled(state);
+    this->bioTextEdit->setEnabled(state);
+
+    this->saveButton->setEnabled(state);
 }
 
 
@@ -176,7 +199,7 @@ void ProfileEditor::findAvatarFile()
                                                      tr("Select avatar image"),
                                                      QDir::homePath(),
                                                      tr("Image files")
-                                                     + "(*.png *.jpg *.jpeg *.gif);;"
+                                                     + " (*.png *.jpg *.jpeg *.gif);;"
                                                      + tr("All files") + " (*)");
 
     if (!newAvatarFilename.isEmpty())
