@@ -81,6 +81,14 @@ ProxyDialog::ProxyDialog(int proxyType,
             this, SLOT(hide()));
 
 
+    // ESC to close
+    closeAction = new QAction(this);
+    closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
+    connect(closeAction, SIGNAL(triggered()),
+            this, SLOT(hide()));
+    this->addAction(closeAction);
+
+
     //////////////////////////////////////////// Layout
     fieldsLayout = new QFormLayout();
     fieldsLayout->addRow(tr("Proxy &Type"),
