@@ -21,6 +21,7 @@
 #include "publisher.h"
 
 Publisher::Publisher(PumpController *pumpController,
+                     GlobalObject *globalObject,
                      QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
@@ -33,6 +34,14 @@ Publisher::Publisher(PumpController *pumpController,
     connect(pController, SIGNAL(listsListReceived(QVariantList)),
             this, SLOT(updateListsMenus(QVariantList)));
 
+
+    this->globalObj = globalObject;
+    connect(globalObj, SIGNAL(messagingModeRequested(QString,QString)),
+            this, SLOT(startMessageForContact(QString,QString)));
+    connect(globalObj, SIGNAL(postEditRequested(QString,QString,QString)),
+            this, SLOT(setEditingMode(QString,QString,QString)));
+
+
     this->postType = "note";
 
     this->editingMode = false; // False unless set from setEditingMode
@@ -635,6 +644,7 @@ void Publisher::setFullMode()
     this->composerBox->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     this->composerBox->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     this->composerBox->setMaximumHeight(2048);
+    this->composerBox->hideInfoMessage();
     this->setMaximumHeight(2048); // i.e. "unlimited"
 
     this->toSelectorButton->show();
@@ -762,11 +772,11 @@ void Publisher::setFileMode()
  * Set Publiser to edit mode, after user clicks on "Edit" in a post
  *
  */
-void Publisher::setEditingMode(QString postID, QString postText,
-                               QString postTitle)
+void Publisher::setEditingMode(QString postId,
+                               QString postTitle, QString postText)
 {
     // Prevent the "Edit" option from destroying a post currently being composed!
-    if (editingMode)
+    if (editingMode || fullMode)
     {
         QMessageBox::warning(this, tr("Error: Already composing"),
                              tr("You can't edit a post at this time, "
@@ -775,7 +785,7 @@ void Publisher::setEditingMode(QString postID, QString postText,
     }
 
     this->editingMode = true;
-    this->editingPostId = postID;
+    this->editingPostId = postId;
     setFullMode();
 
 
@@ -790,15 +800,54 @@ void Publisher::setEditingMode(QString postID, QString postText,
     this->addMediaButton->setDisabled(true);
 
     // Clear these, so it doesn't look like the audience is different than when originally posted
-    this->toPublicFollowersLabel->clear();
+    toPublicAction->setChecked(false);
+    toFollowersAction->setChecked(false);
+    ccPublicAction->setChecked(false);
+    ccFollowersAction->setChecked(false);
     this->toAudienceLabel->clear();
-    this->ccPublicFollowersLabel->clear();
     this->ccAudienceLabel->clear();
 
     this->statusInfoLabel->setText(tr("Editing post"));
 }
 
 
+void Publisher::startMessageForContact(QString name, QString id)
+{
+    if (name.trimmed().isEmpty()) // Ensure "name" has some text in it
+    {
+        name = id;
+    }
+
+    if (fullMode)
+    {
+        QMessageBox::warning(this, tr("Error: Already composing"),
+                             tr("You can't create a message for %1 at "
+                                "this time, because a post is already "
+                                "being composed.").arg(name));
+        return;
+    }
+
+    setFullMode();
+
+    // Unselect Public and Followers from To/CC
+    toPublicAction->setChecked(false);
+    toFollowersAction->setChecked(false);
+    ccPublicAction->setChecked(false);
+    ccFollowersAction->setChecked(false);
+
+
+    // Add user name/ID to the "To" field...
+    this->audienceSelectorTo->copyToSelected(QIcon::fromTheme("user-identity",
+                                                              QIcon(":/images/no-avatar.png")),
+                                             QString("%1 <%2>").arg(name).arg(id));
+    this->audienceSelectorTo->setAudience();
+
+
+    // Set a default title... FIXME?
+    this->titleLineEdit->setText(name + ":");
+}
+
+
 /*
  * After the post is confirmed to have been received by the server
  * re-enable publisher, clear text, etc.
@@ -816,7 +865,7 @@ void Publisher::onPublishingOk()
 }
 
 /*
- * If there was a HTTP error while posting...
+ * If there was an HTTP error while posting...
  *
  */
 void Publisher::onPublishingFailed()
@@ -892,6 +941,7 @@ void Publisher::updateToCcFields(QString selectorType,
     {
         contactRE.indexIn(contactString);
 
+        // FIXME: make links to each profile here
         addressesString.append(contactRE.cap(1).trimmed());
         addressesString.append(", ");
 
