@@ -36,6 +36,7 @@
 
 #include "composer.h"
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "mischelpers.h"
 #include "audienceselector.h"
 
@@ -46,6 +47,7 @@ class Publisher : public QWidget
 
 public:
     explicit Publisher(PumpController *pumpController,
+                       GlobalObject *globalObject,
                        QWidget *parent = 0);
     ~Publisher();
 
@@ -73,9 +75,13 @@ public slots:
     void setVideoMode();
     void setFileMode();
 
-    void setEditingMode(QString postID,
-                        QString postText,
-                        QString postTitle);
+    void setEditingMode(QString postId,
+                        QString postTitle,
+                        QString postText);
+
+
+    void startMessageForContact(QString name,
+                                QString id);
 
     void onPublishingOk();
     void onPublishingFailed();
@@ -172,6 +178,7 @@ private:
     QNetworkReply *uploadNetworkReply;
 
     PumpController *pController;
+    GlobalObject *globalObj;
 };
 
 #endif // PUBLISHER_H
