@@ -22,7 +22,7 @@
 
 PumpController::PumpController(QObject *parent) :  QObject(parent)
 {
-    this->userAgentString = "Dianara/1.2.2";
+    this->userAgentString = "Dianara/1.2.3";
 
     this->postsPerPageMain = 20;
     this->postsPerPageOther = 10;
@@ -304,9 +304,7 @@ void PumpController::updateUserProfile(QString avatarUrl, QString fullName,
     jsonVariant.insert("summary", bio);
 
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     nam.put(updateProfileRequest, data);
     qDebug() << "Updating user profile" << fullName << hometown;
 }
@@ -544,9 +542,7 @@ void PumpController::createPersonList(QString name, QString description)
     jsonVariant.insert("object", jsonVariantObject);
 
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to POST:" << data;
 
 
@@ -612,9 +608,7 @@ void PumpController::addPersonToList(QString listId, QString personId)
     jsonVariant.insert("target", jsonVariantTarget);
 
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to POST:" << data;
 
 
@@ -651,9 +645,7 @@ void PumpController::removePersonFromList(QString listId, QString personId)
     jsonVariant.insert("target", jsonVariantTarget);
 
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to POST:" << data;
 
 
@@ -663,6 +655,102 @@ void PumpController::removePersonFromList(QString listId, QString personId)
 
 
 
+/*
+ * Create a group where users can join and post messages for the other
+ * members, similar to the StatusNet groups.
+ *
+ */
+void PumpController::createGroup(QString name,
+                                 QString summary,
+                                 QString description)
+{
+    qDebug() << "PumpController() creating group:" << name;
+
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
+
+    QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
+                                                       CreateGroupRequest);
+
+    QVariantMap jsonVariantObject;
+    jsonVariantObject.insert("objectType", "group");
+    if (!name.isEmpty())
+    {
+        jsonVariantObject.insert("displayName", name);
+    }
+    jsonVariantObject.insert("summary", summary);
+    jsonVariantObject.insert("content", description);
+
+    QVariantMap jsonVariant;
+    jsonVariant.insert("verb", "create");
+    jsonVariant.insert("object", jsonVariantObject);
+
+
+    QByteArray data = this->prepareJSON(jsonVariant);
+    qDebug() << "About to POST:" << data;
+
+    emit currentJobChanged(tr("Creating group..."));
+    nam.post(postRequest, data);
+}
+
+
+/*
+ * Join a group to be able to send messages to it.
+ * Joining based on ID.
+ *
+ */
+void PumpController::joinGroup(QString id)
+{
+    qDebug() << "PumpController() joining group:" << id;
+
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
+
+    QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
+                                                       JoinGroupRequest);
+
+    QVariantMap jsonVariantObject;
+    jsonVariantObject.insert("objectType", "group");
+    jsonVariantObject.insert("id", id);
+
+    QVariantMap jsonVariant;
+    jsonVariant.insert("verb", "join");
+    jsonVariant.insert("object", jsonVariantObject);
+
+
+    QByteArray data = this->prepareJSON(jsonVariant);
+    qDebug() << "About to POST:" << data;
+
+    emit currentJobChanged(tr("Joining group..."));
+    nam.post(postRequest, data);
+}
+
+
+void PumpController::leaveGroup(QString id)
+{
+    qDebug() << "PumpController() leaving group:" << id;
+
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
+
+    QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
+                                                       LeaveGroupRequest);
+
+    QVariantMap jsonVariantObject;
+    jsonVariantObject.insert("objectType", "group");
+    jsonVariantObject.insert("id", id);
+
+    QVariantMap jsonVariant;
+    jsonVariant.insert("verb", "leave");
+    jsonVariant.insert("object", jsonVariantObject);
+
+
+    QByteArray data = this->prepareJSON(jsonVariant);
+    qDebug() << "About to POST:" << data;
+
+    emit currentJobChanged(tr("Leaving group..."));
+    nam.post(postRequest, data);
+}
+
+
+
 
 /*
  * Get main timeline
@@ -1016,6 +1104,22 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
 }
 
 
+/*
+ * Generate JSON plaintext from a VarianMap.
+ * Uses QJSON at this point, but will use the integrated Qt5 method
+ * when building with Qt5.
+ *
+ */
+QByteArray PumpController::prepareJSON(QVariantMap jsonVariantMap)
+{
+    QJson::Serializer serializer;
+    // bool ok;
+    // QByteArray data = serializer.serialize(jsonVariantMap, &ok);
+
+    // Without using the bool, to make it work with QJSON 0.7.x
+    return serializer.serialize(jsonVariantMap);
+}
+
 
 /*
  * Upload a file to the /uploads feed for the user
@@ -1228,8 +1332,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
         if (requestType != ImageRequest && requestType != AvatarRequest)
         {
             emit showNotification(errorTypeString + "\n"
-                                  + replyUrl + "\n\n"
-                                  + replyFirstLine);
+                                  + replyUrl);
         }
 
         qDebug() << "HTTP 500: Internal Server Error.";
@@ -1289,8 +1392,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
         // if not just an image, it's important, so popup notification too
         if (requestType != ImageRequest && requestType != AvatarRequest)
         {
-            emit showNotification(errorTypeString + "\n" + replyUrl + "\n\n"
-                                  + replyFirstLine);
+            emit showNotification(errorTypeString + "\n"
+                                  + replyUrl);
         }
 
         qDebug() << "HTTP 400: Bad Request.";
@@ -1406,7 +1509,12 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
             if (profileMap.value("id").toString() == "acct:" + this->userId)
             {
-                qDebug() << "Received OWN profile";
+                qDebug() << "Received OWN profile; keys:" << profileMap.keys();
+                qDebug() << "Links from profile:" << profileMap.value("links").toMap().keys();
+                qDebug() << "Lists from profile:" << profileMap.value("lists").toMap()
+                                                               .value("totalItems").toInt();
+                qDebug() << "Lists URL:" << profileMap.value("lists").toMap()
+                                                      .value("url").toString();
                 this->haveProfile = true;
 
                 QString profImageUrl = profileMap.value("image").toMap().value("url").toString();
@@ -1461,38 +1569,44 @@ void PumpController::requestFinished(QNetworkReply *reply)
             emit currentJobChanged(prettyLogMessage);
 
             jsonDataList = jsonData["items"].toList();
-            qDebug() << "Number of items in timeline:" << jsonDataList.size();
+            qDebug() << "Number of items in timeline batch:" << jsonDataList.size();
 
             QString previousLink = jsonData["links"].toMap().value("prev").toMap().value("href").toString();
             QString nextLink = jsonData["links"].toMap().value("next").toMap().value("href").toString();
 
+            int totalItems = jsonData["totalItems"].toInt();
+
             if (requestType == MainTimelineRequest)
             {
                 qDebug() << "It was the main timeline";
                 this->haveMainTL = true;
                 emit mainTimelineReceived(jsonDataList, this->postsPerPageMain,
-                                          previousLink, nextLink);
+                                          previousLink, nextLink,
+                                          totalItems);
             }
             else if (requestType == DirectTimelineRequest)
             {
                 qDebug() << "It was the direct messages timeline";
                 this->haveDirectTL = true;
                 emit directTimelineReceived(jsonDataList, this->postsPerPageOther,
-                                            previousLink, nextLink);
+                                            previousLink, nextLink,
+                                            totalItems);
             }
             else if (requestType == ActivityTimelineRequest)
             {
                 qDebug() << "It was the own activity timeline";
                 this->haveActivityTL = true;
                 emit activityTimelineReceived(jsonDataList, this->postsPerPageOther,
-                                              previousLink, nextLink);
+                                              previousLink, nextLink,
+                                              totalItems);
             }
             else if (requestType == FavoritesTimelineRequest)
             {
                 qDebug() << "It was the favorites timeline";
                 this->haveFavoritesTL = true;
                 emit favoritesTimelineReceived(jsonDataList, this->postsPerPageOther,
-                                               previousLink, nextLink);
+                                               previousLink, nextLink,
+                                               totalItems);
             }
         }
         else
@@ -1594,7 +1708,9 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     ///////////////////////////////////// If liking a post was requested
     case LikePostRequest:
-        emit currentJobChanged(tr("Message liked or unliked successfully."));
+        prettyLogMessage = tr("Message liked or unliked successfully.");
+        emit currentJobChanged(prettyLogMessage);
+        emit logMessage(prettyLogMessage);
 
         emit likeSet();
         break;
@@ -1715,15 +1831,19 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
             if (requestType == FollowContactRequest)
             {
-                prettyLogMessage = tr("Following %1 successfully.",
-                                      "%1 is a person's ID").arg(contact->getId());
+                prettyLogMessage = tr("Following %1 (%2) successfully.",
+                                      "%1 is a person's name, %2 is the ID")
+                                   .arg(contact->getName())
+                                   .arg(contact->getId());
 
                 emit contactFollowed(contact);
             }
             else
             {
-                prettyLogMessage = tr("Stopped following %1 successfully.",
-                                      "%1 is a person's ID").arg(contact->getId());
+                prettyLogMessage = tr("Stopped following %1 (%2) successfully.",
+                                      "%1 is a person's name, %2 is the ID")
+                                   .arg(contact->getName())
+                                   .arg(contact->getId());
 
                 emit contactUnfollowed(contact);
             }
@@ -1840,10 +1960,15 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
         break;
 
+    ///////////////////////////////////////////////////////////////////// Lists
 
     // Person list created OK
     case CreatePersonListRequest:
-        emit currentJobChanged(tr("Person list created successfully."));
+        prettyLogMessage = tr("Person list '%1' created successfully.")
+                           .arg(jsonData.value("object").toMap()
+                                        .value("displayName").toString());
+        emit currentJobChanged(prettyLogMessage);
+        emit logMessage(prettyLogMessage);
 
         this->getListsList(); // And reload the person lists (FIXME!)
         break;
@@ -1851,7 +1976,10 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     // Person list created OK
     case DeletePersonListRequest:
-        emit currentJobChanged(tr("Person list deleted successfully."));
+        prettyLogMessage = tr("Person list deleted successfully.");
+        emit currentJobChanged(prettyLogMessage);
+        emit logMessage(prettyLogMessage);
+
 
         this->getListsList(); // And reload the person lists (FIXME!)
         break;
@@ -1892,13 +2020,20 @@ void PumpController::requestFinished(QNetworkReply *reply)
     case AddMemberToListRequest:
         if (jsonParsedOK && jsonData.size() > 0)
         {
-            QString personId = jsonData.value("object").toMap().value("id").toString();
-            QString personName = jsonData.value("object").toMap().value("displayName").toString();
-            QString personAvatar = jsonData.value("object").toMap().value("image").toMap().value("url").toString();
+            QString personId = ASPerson::cleanupId(jsonData.value("object").toMap()
+                                                           .value("id").toString());
+            QString personName = jsonData.value("object").toMap()
+                                         .value("displayName").toString();
+            QString personAvatar = jsonData.value("object").toMap()
+                                           .value("image").toMap()
+                                           .value("url").toString();
 
             emit personAddedToList(personId, personName, personAvatar);
 
-            prettyLogMessage = tr("Person added to list successfully.");
+            prettyLogMessage = tr("%1 (%2) added to list successfully.",
+                                  "1=contact name, 2=contact ID")
+                               .arg(personName)
+                               .arg(personId);
             emit currentJobChanged(prettyLogMessage);
             emit logMessage(prettyLogMessage);
         }
@@ -1909,17 +2044,60 @@ void PumpController::requestFinished(QNetworkReply *reply)
     case RemoveMemberFromListRequest:
         if (jsonParsedOK && jsonData.size() > 0)
         {
-            QString personId = jsonData.value("object").toMap().value("id").toString();
+            QString personId = ASPerson::cleanupId(jsonData.value("object").toMap()
+                                                            .value("id").toString());
+            QString personName = jsonData.value("object").toMap()
+                                         .value("displayName").toString();
 
             emit personRemovedFromList(personId);
 
-            prettyLogMessage = tr("Person removed from list successfully.");
+            prettyLogMessage = tr("%1 (%2) removed from list successfully.",
+                                  "1=contact name, 2=contact ID")
+                               .arg(personName)
+                               .arg(personId);
             emit currentJobChanged(prettyLogMessage);
             emit logMessage(prettyLogMessage);
         }
         break;
 
 
+    //////////////////////////////////////////////////////////////////// Groups
+    case CreateGroupRequest:
+        prettyLogMessage = tr("Group %1 created successfully.")
+                             .arg(jsonData.value("object").toMap()
+                                          .value("displayName").toString());
+        emit currentJobChanged(prettyLogMessage);
+        emit logMessage(prettyLogMessage);
+        qDebug() << "Group created; ==========================";
+        qDebug() << "ID:" << jsonData.value("object").toMap().value("id").toString();
+
+        break;
+
+
+    case JoinGroupRequest:
+        prettyLogMessage = tr("Group %1 joined successfully.")
+                             .arg(jsonData.value("object").toMap()
+                                          .value("displayName").toString());
+        emit currentJobChanged(prettyLogMessage);
+        emit logMessage(prettyLogMessage);
+
+        qDebug() << "Group joined; ==========================";
+        qDebug() << "Keys: " << jsonData.keys();
+        qDebug() << jsonData.value("object").toString();
+
+        break;
+
+
+    case LeaveGroupRequest:
+        prettyLogMessage = tr("Left the %1 group successfully.")
+                             .arg(jsonData.value("object").toMap()
+                                          .value("displayName").toString());
+        emit currentJobChanged(prettyLogMessage);
+        emit logMessage(prettyLogMessage);
+
+        break;
+
+
 
     case AvatarRequest:
         qDebug() << "Received AVATAR data, from " << replyUrl;
@@ -2416,6 +2594,7 @@ void PumpController::postNote(QMap<QString, QString> audienceMap,
     {
         jsonVariantObject.insert("displayName", postTitle);
     }
+    //jsonVariantObject.insert("summary", "summary test");
     jsonVariantObject.insert("content", postText);
 
     QVariantMap jsonVariant;
@@ -2427,14 +2606,7 @@ void PumpController::postNote(QMap<QString, QString> audienceMap,
     jsonVariant.insert("cc", audience.at(1));
 
 
-    QJson::Serializer serializer;
-    // bool ok;
-    // QByteArray data = serializer.serialize(jsonVariant, &ok);
-
-    // This way to make it work with QJSON 0.7.x
-    QByteArray data = serializer.serialize(jsonVariant);
-
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to POST:" << data;
 
     nam.post(postRequest, data);
@@ -2500,9 +2672,7 @@ void PumpController::postMediaStepTwo(QString id)
     jsonVariant.insert("cc", audience.at(1));
 
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to POST:" << data;
     nam.post(postRequest, data);
 }
@@ -2531,9 +2701,8 @@ void PumpController::postMediaStepThree(QString id)
     }
     jsonVariant.insert("content", this->currentPostDescription);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to PUT:" << data;
     nam.put(postRequest, data);
 }
@@ -2548,37 +2717,34 @@ void PumpController::postMediaStepThree(QString id)
  */
 void PumpController::postAvatarStepTwo(QString id)
 {
-        qDebug() << "PumpController::postAvatarStepTwo() image ID:" << id;
+    qDebug() << "PumpController::postAvatarStepTwo() image ID:" << id;
 
-        QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
 
-        QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
-                                                           PublishAvatarRequest);
+    QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
+                                                       PublishAvatarRequest);
+
+    QVariantMap jsonVariantObject;
+    jsonVariantObject.insert("objectType", "image");
+    jsonVariantObject.insert("id", id);
+
+    // audience, CC: Public
+    QVariantMap jsonVariantPublic;
+    jsonVariantPublic.insert("objectType", "collection");
+    jsonVariantPublic.insert("id", "http://activityschema.org/collection/public");
+
+    QVariantList jsonVariantAudience;
+    jsonVariantAudience.append(jsonVariantPublic);
+
+    QVariantMap jsonVariant;
+    jsonVariant.insert("verb", "post");
+    jsonVariant.insert("object", jsonVariantObject);
+    jsonVariant.insert("cc", jsonVariantAudience); // CC: Public
 
 
-        QVariantMap jsonVariantObject;
-        jsonVariantObject.insert("objectType", "image");
-        jsonVariantObject.insert("id", id);
-
-        // audience, CC: Public
-        QVariantMap jsonVariantPublic;
-        jsonVariantPublic.insert("objectType", "collection");
-        jsonVariantPublic.insert("id", "http://activityschema.org/collection/public");
-
-        QVariantList jsonVariantAudience;
-        jsonVariantAudience.append(jsonVariantPublic);
-
-        QVariantMap jsonVariant;
-        jsonVariant.insert("verb", "post");
-        jsonVariant.insert("object", jsonVariantObject);
-        jsonVariant.insert("cc", jsonVariantAudience); // CC: Public
-
-        QJson::Serializer serializer;
-        QByteArray data = serializer.serialize(jsonVariant);
-
-        qDebug() << "About to POST:" << data;
-
-        nam.post(postRequest, data);
+    QByteArray data = this->prepareJSON(jsonVariant);
+    qDebug() << "About to POST:" << data;
+    nam.post(postRequest, data);
 }
 
 
@@ -2603,9 +2769,8 @@ void PumpController::updatePost(QString id,
     jsonVariant.insert("displayName", title); // "title" can be empty, as a way to remove titles
     jsonVariant.insert("content", content);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to PUT:" << data;
     nam.put(postRequest, data);
 }
@@ -2635,11 +2800,9 @@ void PumpController::likePost(QString postID, QString postType, bool like)
     jsonVariant.insert("verb", like ? "favorite":"unfavorite"); // like or unlike
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(likeRequest, data);
 }
 
@@ -2668,11 +2831,8 @@ void PumpController::addComment(QString comment, QString postID, QString postTyp
     jsonVariant.insert("verb", "post");
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
-
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(commentRequest, data);
 }
 
@@ -2694,9 +2854,8 @@ void PumpController::updateComment(QString id, QString content)
     jsonVariant.insert("verb", "update");
     jsonVariant.insert("content", content);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "About to PUT:" << data;
     nam.put(postRequest, data);
 }
@@ -2722,11 +2881,9 @@ void PumpController::sharePost(QString postID, QString postType)
     jsonVariant.insert("verb", "share");
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(shareRequest, data);
 }
 
@@ -2749,11 +2906,9 @@ void PumpController::unsharePost(QString postId, QString postType)
     jsonVariant.insert("verb", "unshare");
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(unshareRequest, data);
 }
 
@@ -2776,11 +2931,9 @@ void PumpController::deletePost(QString postID, QString postType)
     jsonVariant.insert("verb", "delete");
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(deleteRequest, data);
 }
 
@@ -2811,11 +2964,9 @@ void PumpController::followContact(QString address)
     jsonVariant.insert("verb", "follow");
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(followRequest, data);
 }
 
@@ -2845,10 +2996,8 @@ void PumpController::unfollowContact(QString address)
     jsonVariant.insert("verb", "stop-following");
     jsonVariant.insert("object", jsonVariantObject);
 
-    QJson::Serializer serializer;
-    QByteArray data = serializer.serialize(jsonVariant);
 
+    QByteArray data = this->prepareJSON(jsonVariant);
     qDebug() << "about to POST:" << data;
-
     nam.post(unfollowRequest, data);
 }
