@@ -22,11 +22,13 @@
 
 TimeLine::TimeLine(int timelineType,
                    PumpController *pumpController,
+                   GlobalObject *globalObject,
                    FilterChecker *filterChecker,
                    QWidget *parent) :  QWidget(parent)
 {
     this->timelineType = timelineType;
     this->pController = pumpController;
+    this->globalObj = globalObject;
     this->fChecker = filterChecker;
 
     // Set 6 empty colors initially
@@ -37,20 +39,20 @@ TimeLine::TimeLine(int timelineType,
 
     // Simulated data for demo posts
     QVariantMap demoLocationData;
-    demoLocationData.insert("displayName", "Demoville");
+    demoLocationData.insert("displayName",  "Demoville");
 
     QVariantMap demoAuthorData;
-    demoAuthorData.insert("displayName", "Demo User");
-    demoAuthorData.insert("id",          "demo@somepump.example");
-    demoAuthorData.insert("location",    demoLocationData);
-    demoAuthorData.insert("summary",     "I am not a real user");
+    demoAuthorData.insert("displayName",    "Demo User");
+    demoAuthorData.insert("id",             "demo@somepump.example");
+    demoAuthorData.insert("location",       demoLocationData);
+    demoAuthorData.insert("summary",        "I am not a real user");
 
     QVariantMap demoGeneratorData;
     demoGeneratorData.insert("displayName", "Dianara");
 
     QVariantMap demoObjectData;
-    demoObjectData.insert("published",   "2013-05-01T00:00:00Z");
-    demoObjectData.insert("objectType",  "note");
+    demoObjectData.insert("objectType",     "note");
+    demoObjectData.insert("published",      "2013-05-01T00:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -102,7 +104,7 @@ TimeLine::TimeLine(int timelineType,
                               + "</a>"
                               + "<br><br>");
 
-        this->previousNewestPostId = settings.value("previousNewestPostIdMain", "").toString();
+        this->previousNewestPostId = settings.value("previousNewestPostIdMain").toString();
         break;
 
 
@@ -111,7 +113,7 @@ TimeLine::TimeLine(int timelineType,
         demoObjectData.insert("content",      tr("Here, you'll see posts "
                                                  "specifically directed to you.")
                                               + "<br><br>");
-        this->previousNewestPostId = settings.value("previousNewestPostIdDirect", "").toString();
+        this->previousNewestPostId = settings.value("previousNewestPostIdDirect").toString();
         break;
 
 
@@ -119,7 +121,7 @@ TimeLine::TimeLine(int timelineType,
         demoObjectData.insert("displayName", tr("Activity Timeline"));
         demoObjectData.insert("content",     tr("You'll see your own posts here.")
                                              + "<br><br>");
-        this->previousNewestPostId = settings.value("previousNewestPostIdActivity", "").toString();
+        this->previousNewestPostId = settings.value("previousNewestPostIdActivity").toString();
         break;
 
 
@@ -127,7 +129,7 @@ TimeLine::TimeLine(int timelineType,
         demoObjectData.insert("displayName", tr("Favorites Timeline"));
         demoObjectData.insert("content",     tr("Posts and comments you've liked.")
                                              + "<br><br>");
-        this->previousNewestPostId = settings.value("previousNewestPostIdFavorites", "").toString();
+        this->previousNewestPostId = settings.value("previousNewestPostIdFavorites").toString();
         break;
 
 
@@ -150,19 +152,23 @@ TimeLine::TimeLine(int timelineType,
 
     this->minMaxHeightForPosts = 400;
 
-    firstPageButton = new QPushButton(QIcon::fromTheme("go-first"), tr("&Newest"));
+    firstPageButton = new QPushButton(QIcon::fromTheme("go-first"),
+                                      tr("Newest"));
     connect(firstPageButton, SIGNAL(clicked()),
             this, SLOT(goToFirstPage()));
 
+    // FIXME: turn this into a button, that will allow to jump to any page
     currentPageLabel = new QLabel();
     currentPageLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     currentPageLabel->setSizePolicy(QSizePolicy::Minimum,
                                     QSizePolicy::Maximum);
 
-    previousPageButton = new QPushButton(QIcon::fromTheme("go-previous"), tr("Newer &Posts"));
+    previousPageButton = new QPushButton(QIcon::fromTheme("go-previous"),
+                                         tr("Newer"));
     connect(previousPageButton, SIGNAL(clicked()),
             this, SLOT(goToPreviousPage()));
-    nextPageButton = new QPushButton(QIcon::fromTheme("go-next"), tr("&Older Posts"));
+    nextPageButton = new QPushButton(QIcon::fromTheme("go-next"),
+                                     tr("Older"));
     connect(nextPageButton, SIGNAL(clicked()),
             this, SLOT(goToNextPage()));
 
@@ -192,7 +198,9 @@ TimeLine::TimeLine(int timelineType,
     this->setLayout(mainLayout);
 
 
-    // QActions for better keyboard control, single step
+    ////////////////////////////////////// QActions for better keyboard control
+
+    // Single step
     scrollUpAction = new QAction(this);
     scrollUpAction->setShortcut(QKeySequence("Ctrl+Up"));
     connect(scrollUpAction, SIGNAL(triggered()),
@@ -231,6 +239,7 @@ TimeLine::TimeLine(int timelineType,
             this, SLOT(scrollToBottom()));
     this->addAction(scrollBottomAction);
 
+
     // Previous/Next page in timeline
     previousPageAction = new QAction(this);
     previousPageAction->setShortcut(QKeySequence("Ctrl+Left"));
@@ -252,6 +261,7 @@ TimeLine::TimeLine(int timelineType,
                               false, // Not highlighted
                               false, // Not standalone
                               pController,
+                              globalObj,
                               this);
     demoPost->setMinMaxHeight(this->minMaxHeightForPosts);
 
@@ -341,13 +351,25 @@ void TimeLine::requestTimelinePage()
 /*
  *  Update the label at the bottom of the page, indicating current "page"
  *
+ *  FIXME: turn the label into a button, that will show a dialog to jump to any page
  */
 void TimeLine::updateCurrentPageNumber()
 {
-    QString currentPageString;
-    currentPageString = QString("%1").arg((this->timelineOffset / this->postsPerPage) + 1);
+    int currentPage = (this->timelineOffset / this->postsPerPage) + 1;
+    int totalPages = qCeil(this->totalItemsCount / (float)this->postsPerPage);
 
-    this->currentPageLabel->setText(currentPageString);
+    this->currentPageLabel->setText(QString("%1 / %2")
+                                    .arg(currentPage)
+                                    .arg(totalPages));
+    this->currentPageLabel->setToolTip(tr("Page %1 of %2.")
+                                       .arg(currentPage)
+                                       .arg(totalPages)
+                                       + "\n"
+                                       + tr("Showing %1 posts per page.")
+                                         .arg(this->postsPerPage)
+                                       + "\n"
+                                       + tr("%1 posts in total.")
+                                         .arg(this->totalItemsCount));
 }
 
 void TimeLine::setMinMaxHeightForPosts(int newMinMaxHeightForPosts)
@@ -408,7 +430,8 @@ void TimeLine::updateHighlightColors(QStringList colorList)
 
 
 void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
-                                   QString previousLink, QString nextLink)
+                                   QString previousLink, QString nextLink,
+                                   int totalItems)
 {
     qDebug() << "TimeLine::setTimeLineContents()";
 
@@ -424,7 +447,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
     this->hide();
 
     this->postsPerPage = postsPerPage;
-
+    this->totalItemsCount = totalItems;
 
     int newPostCount = 0;
     bool allNewPostsCounted = false;
@@ -493,7 +516,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                 }
                 else
                 {
-                    // If post is NOT deleted, and not ours, add it to the count
+                    // If post is NOT deleted or filtered, and not ours, add it to the count
                     if (postDeletedTime.isEmpty()
                         && filtered != FilterChecker::FilterOut
                         && activity->author()->getId() != pController->currentUserId()
@@ -516,7 +539,6 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                 if (filtered == FilterChecker::Highlight)
                 {
                     highlightedByFilter = true;
-                    // FIXME, count highlighted posts
                 }
 
                 Post *newPost = new Post(activity,
@@ -524,12 +546,13 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                                          highlightedByFilter,
                                          false,  // NOT standalone
                                          pController,
+                                         globalObj,
                                          this);
                 if (postIsNew)
                 {
                     newPost->setPostAsNew();
-                    connect(newPost, SIGNAL(postRead()),
-                            this, SLOT(decreaseUnreadPostsCount()));
+                    connect(newPost, SIGNAL(postRead(bool)),
+                            this, SLOT(decreaseUnreadPostsCount(bool)));
 
                     if (newPost->getHighlightType() != Post::NoHighlight)
                     {
@@ -540,8 +563,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                 this->postsInTimeline.append(newPost);
                 this->postsLayout->addWidget(newPost);
 
-                connect(newPost, SIGNAL(postEditRequested(QString,QString,QString)),
-                        this, SIGNAL(postEditRequested(QString,QString,QString)));
+                // FIXME: this signal should go directly via a global shared object, instead
                 connect(newPost, SIGNAL(commentingOnPost(QWidget*)),
                         this, SIGNAL(commentingOnPost(QWidget*)));
             }
@@ -553,6 +575,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                 qDebug() << "Filter action:" << filtered
                          << "(0=filter out; 1=highlight, 999=no filtering)";
 
+                // FIXME: show something in place of the deleted post
+
                 delete activity;
             }
         }
@@ -571,7 +595,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
     this->previousNewestPostId = newestPostId;
     this->unreadPostsCount = newPostCount;
     qDebug() << "New posts:" << newPostCount << "; Newest post ID:" << previousNewestPostId
-             << "\nHighlighted posts:" << newHighlightedPostsCount;
+             << "\nHighlighted posts:" << newHighlightedPostsCount
+             << "\nTotal posts:" << totalItemsCount;
 
 
     this->updateCurrentPageNumber();
@@ -579,7 +604,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
 
     emit timelineRendered(this->timelineType,
                           unreadPostsCount,
-                          newHighlightedPostsCount);
+                          newHighlightedPostsCount,
+                          totalItemsCount);
 
     // Show timeline again, since everything is added and drawn
     this->show();
@@ -732,11 +758,17 @@ void TimeLine::scrollToBottom()
  * the parent window, so it can update its tab titles
  *
  */
-void TimeLine::decreaseUnreadPostsCount()
+void TimeLine::decreaseUnreadPostsCount(bool wasHighlighted)
 {
     --unreadPostsCount;
 
+    if (wasHighlighted)
+    {
+        --newHighlightedPostsCount;
+    }
+
     emit unreadPostsCountChanged(this->timelineType,
                                  this->unreadPostsCount,
-                                 this->newHighlightedPostsCount);
+                                 this->newHighlightedPostsCount,
+                                 this->totalItemsCount);
 }
