@@ -27,10 +27,12 @@
 #include <QVariantList>
 #include <QMap>
 #include <QPushButton>
+#include <QtCore/qmath.h>
 
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "globalobject.h"
 #include "asobject.h"
 #include "asactivity.h"
 #include "post.h"
@@ -44,6 +46,7 @@ class TimeLine : public QWidget
 public:
     TimeLine(int timelineType,
              PumpController *pumpController,
+             GlobalObject *globalObject,
              FilterChecker *filterChecker,
              QWidget *parent = 0);
     ~TimeLine();
@@ -81,21 +84,20 @@ signals:
 
     void timelineRendered(int timelineType,
                           int newPostCount,
-                          int highlightedPostsCount);
+                          int highlightedPostsCount,
+                          int totalItemsCount);
     void unreadPostsCountChanged(int timelineType,
                                  int newPostCount,
-                                 int highlightedCount);
-
-    void postEditRequested(QString originalPostID,
-                           QString contents,
-                           QString title);
+                                 int highlightedCount,
+                                 int totalItemsCount);
 
     void commentingOnPost(QWidget *commenterWidget);
 
 
 public slots:
     void setTimeLineContents(QVariantList postList, int postsPerPage,
-                             QString previousLink, QString nextLink);
+                             QString previousLink, QString nextLink,
+                             int totalItems);
 
     void setLikesInPost(QVariantList likesList, QString originatingPostURL);
     void setCommentsInPost(QVariantList commentsList, QString originatingPostURL);
@@ -111,7 +113,7 @@ public slots:
     void scrollToTop();
     void scrollToBottom();
 
-    void decreaseUnreadPostsCount();
+    void decreaseUnreadPostsCount(bool wasHighlighted);
 
 protected:
 
@@ -122,6 +124,7 @@ private:
     QHBoxLayout *bottomLayout;
 
     PumpController *pController;
+    GlobalObject *globalObj;
     FilterChecker *fChecker;
 
     QPushButton *firstPageButton;
@@ -148,6 +151,7 @@ private:
     int postsPerPage;
     int unreadPostsCount;
     int newHighlightedPostsCount;
+    int totalItemsCount;
 
     int minMaxHeightForPosts;
 
